Class: Aws::ElasticsearchService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ElasticsearchService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-elasticsearchservice/client.rb,
sig/client.rbs
Overview
An API client for ElasticsearchService. To construct a client, you need to configure a :region and :credentials.
client = Aws::ElasticsearchService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptInboundCrossClusterSearchConnectionResponseSuccess, _AssociatePackageResponseSuccess, _AuthorizeVpcEndpointAccessResponseSuccess, _CancelDomainConfigChangeResponseSuccess, _CancelElasticsearchServiceSoftwareUpdateResponseSuccess, _CreateElasticsearchDomainResponseSuccess, _CreateOutboundCrossClusterSearchConnectionResponseSuccess, _CreatePackageResponseSuccess, _CreateVpcEndpointResponseSuccess, _DeleteElasticsearchDomainResponseSuccess, _DeleteInboundCrossClusterSearchConnectionResponseSuccess, _DeleteOutboundCrossClusterSearchConnectionResponseSuccess, _DeletePackageResponseSuccess, _DeleteVpcEndpointResponseSuccess, _DescribeDomainAutoTunesResponseSuccess, _DescribeDomainChangeProgressResponseSuccess, _DescribeElasticsearchDomainConfigResponseSuccess, _DescribeElasticsearchDomainResponseSuccess, _DescribeElasticsearchDomainsResponseSuccess, _DescribeElasticsearchInstanceTypeLimitsResponseSuccess, _DescribeInboundCrossClusterSearchConnectionsResponseSuccess, _DescribeOutboundCrossClusterSearchConnectionsResponseSuccess, _DescribePackagesResponseSuccess, _DescribeReservedElasticsearchInstanceOfferingsResponseSuccess, _DescribeReservedElasticsearchInstancesResponseSuccess, _DescribeVpcEndpointsResponseSuccess, _DissociatePackageResponseSuccess, _GetCompatibleElasticsearchVersionsResponseSuccess, _GetPackageVersionHistoryResponseSuccess, _GetUpgradeHistoryResponseSuccess, _GetUpgradeStatusResponseSuccess, _ListDomainNamesResponseSuccess, _ListDomainsForPackageResponseSuccess, _ListElasticsearchInstanceTypesResponseSuccess, _ListElasticsearchVersionsResponseSuccess, _ListPackagesForDomainResponseSuccess, _ListTagsResponseSuccess, _ListVpcEndpointAccessResponseSuccess, _ListVpcEndpointsForDomainResponseSuccess, _ListVpcEndpointsResponseSuccess, _PurchaseReservedElasticsearchInstanceOfferingResponseSuccess, _RejectInboundCrossClusterSearchConnectionResponseSuccess, _RevokeVpcEndpointAccessResponseSuccess, _StartElasticsearchServiceSoftwareUpdateResponseSuccess, _UpdateElasticsearchDomainConfigResponseSuccess, _UpdatePackageResponseSuccess, _UpdateVpcEndpointResponseSuccess, _UpgradeElasticsearchDomainResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::AcceptInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to accept an inbound cross-cluster search connection request.
-
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Elasticsearch domain.
-
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon ES domain.
-
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
-
#cancel_elasticsearch_service_software_update(params = {}) ⇒ Types::CancelElasticsearchServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon ES domain.
-
#create_elasticsearch_domain(params = {}) ⇒ Types::CreateElasticsearchDomainResponse
Creates a new Elasticsearch domain.
-
#create_outbound_cross_cluster_search_connection(params = {}) ⇒ Types::CreateOutboundCrossClusterSearchConnectionResponse
Creates a new cross-cluster search connection from a source domain to a destination domain.
-
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Create a package for use with Amazon ES domains.
-
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
-
#delete_elasticsearch_domain(params = {}) ⇒ Types::DeleteElasticsearchDomainResponse
Permanently deletes the specified Elasticsearch domain and all of its data.
-
#delete_elasticsearch_service_role(params = {}) ⇒ Struct
Deletes the service-linked role that Elasticsearch Service uses to manage and maintain VPC domains.
-
#delete_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::DeleteInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to delete an existing inbound cross-cluster search connection.
-
#delete_outbound_cross_cluster_search_connection(params = {}) ⇒ Types::DeleteOutboundCrossClusterSearchConnectionResponse
Allows the source domain owner to delete an existing outbound cross-cluster search connection.
-
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Delete the package.
-
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Provides scheduled Auto-Tune action details for the Elasticsearch domain, such as Auto-Tune action type, description, severity, and scheduled date.
-
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on a domain, including a change ID, status, and progress stages.
-
#describe_elasticsearch_domain(params = {}) ⇒ Types::DescribeElasticsearchDomainResponse
Returns domain configuration information about the specified Elasticsearch domain, including the domain ID, domain endpoint, and domain ARN.
-
#describe_elasticsearch_domain_config(params = {}) ⇒ Types::DescribeElasticsearchDomainConfigResponse
Provides cluster configuration information about the specified Elasticsearch domain, such as the state, creation date, update version, and update date for cluster options.
-
#describe_elasticsearch_domains(params = {}) ⇒ Types::DescribeElasticsearchDomainsResponse
Returns domain configuration information about the specified Elasticsearch domains, including the domain ID, domain endpoint, and domain ARN.
-
#describe_elasticsearch_instance_type_limits(params = {}) ⇒ Types::DescribeElasticsearchInstanceTypeLimitsResponse
Describe Elasticsearch Limits for a given InstanceType and ElasticsearchVersion.
-
#describe_inbound_cross_cluster_search_connections(params = {}) ⇒ Types::DescribeInboundCrossClusterSearchConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination domain.
-
#describe_outbound_cross_cluster_search_connections(params = {}) ⇒ Types::DescribeOutboundCrossClusterSearchConnectionsResponse
Lists all the outbound cross-cluster search connections for a source domain.
-
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to Amazon ES.
-
#describe_reserved_elasticsearch_instance_offerings(params = {}) ⇒ Types::DescribeReservedElasticsearchInstanceOfferingsResponse
Lists available reserved Elasticsearch instance offerings.
-
#describe_reserved_elasticsearch_instances(params = {}) ⇒ Types::DescribeReservedElasticsearchInstancesResponse
Returns information about reserved Elasticsearch instances for this account.
-
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
-
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Dissociates a package from the Amazon ES domain.
-
#get_compatible_elasticsearch_versions(params = {}) ⇒ Types::GetCompatibleElasticsearchVersionsResponse
Returns a list of upgrade compatible Elastisearch versions.
-
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of versions of the package, along with their creation time and commit message.
-
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades that were performed on the domain.
-
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.
-
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the name of all Elasticsearch domains owned by the current user's account.
-
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon ES domains associated with the package.
-
#list_elasticsearch_instance_types(params = {}) ⇒ Types::ListElasticsearchInstanceTypesResponse
List all Elasticsearch instance types that are supported for given ElasticsearchVersion.
-
#list_elasticsearch_versions(params = {}) ⇒ Types::ListElasticsearchVersionsResponse
List all supported Elasticsearch versions.
-
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with the Amazon ES domain.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all tags for the given Elasticsearch domain.
-
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current account and Region.
-
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
-
#purchase_reserved_elasticsearch_instance_offering(params = {}) ⇒ Types::PurchaseReservedElasticsearchInstanceOfferingResponse
Allows you to purchase reserved Elasticsearch instances.
-
#reject_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::RejectInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to reject an inbound cross-cluster search connection request.
-
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from the specified Elasticsearch domain.
-
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
-
#start_elasticsearch_service_software_update(params = {}) ⇒ Types::StartElasticsearchServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon ES domain.
-
#update_elasticsearch_domain_config(params = {}) ⇒ Types::UpdateElasticsearchDomainConfigResponse
Modifies the cluster configuration of the specified Elasticsearch domain, setting as setting the instance type and the number of instances.
-
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon ES domains.
-
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#upgrade_elasticsearch_domain(params = {}) ⇒ Types::UpgradeElasticsearchDomainResponse
Allows you to either upgrade your domain or perform an Upgrade eligibility check to a compatible Elasticsearch version.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3673 3674 3675 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3673 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3676 3677 3678 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3676 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::AcceptInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to accept an inbound cross-cluster search connection request.
86 |
# File 'sig/client.rbs', line 86
def accept_inbound_cross_cluster_search_connection: (
|
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Elasticsearch domain. Tags are a set of case-sensitive key value pairs. An Elasticsearch domain may have up to 10 tags. See Tagging Amazon Elasticsearch Service Domains for more information.
92 |
# File 'sig/client.rbs', line 92
def add_tags: (
|
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon ES domain.
108 |
# File 'sig/client.rbs', line 108
def associate_package: (
|
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
119 |
# File 'sig/client.rbs', line 119
def authorize_vpc_endpoint_access: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3646 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ElasticsearchService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-elasticsearchservice' context[:gem_version] = '1.126.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
132 |
# File 'sig/client.rbs', line 132
def cancel_domain_config_change: (
|
#cancel_elasticsearch_service_software_update(params = {}) ⇒ Types::CancelElasticsearchServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon ES domain.
You can only perform this operation before the AutomatedUpdateDate
and when the UpdateStatus is in the PENDING_UPDATE state.
143 |
# File 'sig/client.rbs', line 143
def cancel_elasticsearch_service_software_update: (
|
#create_elasticsearch_domain(params = {}) ⇒ Types::CreateElasticsearchDomainResponse
Creates a new Elasticsearch domain. For more information, see Creating Elasticsearch Domains in the Amazon Elasticsearch Service Developer Guide.
153 |
# File 'sig/client.rbs', line 153
def create_elasticsearch_domain: (
|
#create_outbound_cross_cluster_search_connection(params = {}) ⇒ Types::CreateOutboundCrossClusterSearchConnectionResponse
Creates a new cross-cluster search connection from a source domain to a destination domain.
232 |
# File 'sig/client.rbs', line 232
def create_outbound_cross_cluster_search_connection: (
|
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Create a package for use with Amazon ES domains.
252 |
# File 'sig/client.rbs', line 252
def create_package: (
|
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
268 |
# File 'sig/client.rbs', line 268
def create_vpc_endpoint: (
|
#delete_elasticsearch_domain(params = {}) ⇒ Types::DeleteElasticsearchDomainResponse
Permanently deletes the specified Elasticsearch domain and all of its data. Once a domain is deleted, it cannot be recovered.
283 |
# File 'sig/client.rbs', line 283
def delete_elasticsearch_domain: (
|
#delete_elasticsearch_service_role(params = {}) ⇒ Struct
Deletes the service-linked role that Elasticsearch Service uses to manage and maintain VPC domains. Role deletion will fail if any existing VPC domains use the role. You must delete any such Elasticsearch domains before deleting the role. See Deleting Elasticsearch Service Role in VPC Endpoints for Amazon Elasticsearch Service Domains.
289 290 |
# File 'sig/client.rbs', line 289
def delete_elasticsearch_service_role: () -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
|
#delete_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::DeleteInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to delete an existing inbound cross-cluster search connection.
297 |
# File 'sig/client.rbs', line 297
def delete_inbound_cross_cluster_search_connection: (
|
#delete_outbound_cross_cluster_search_connection(params = {}) ⇒ Types::DeleteOutboundCrossClusterSearchConnectionResponse
Allows the source domain owner to delete an existing outbound cross-cluster search connection.
307 |
# File 'sig/client.rbs', line 307
def delete_outbound_cross_cluster_search_connection: (
|
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Delete the package.
317 |
# File 'sig/client.rbs', line 317
def delete_package: (
|
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
327 |
# File 'sig/client.rbs', line 327
def delete_vpc_endpoint: (
|
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Provides scheduled Auto-Tune action details for the Elasticsearch domain, such as Auto-Tune action type, description, severity, and scheduled date.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
338 |
# File 'sig/client.rbs', line 338
def describe_domain_auto_tunes: (
|
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on a domain, including a change ID, status, and progress stages.
350 |
# File 'sig/client.rbs', line 350
def describe_domain_change_progress: (
|
#describe_elasticsearch_domain(params = {}) ⇒ Types::DescribeElasticsearchDomainResponse
Returns domain configuration information about the specified Elasticsearch domain, including the domain ID, domain endpoint, and domain ARN.
361 |
# File 'sig/client.rbs', line 361
def describe_elasticsearch_domain: (
|
#describe_elasticsearch_domain_config(params = {}) ⇒ Types::DescribeElasticsearchDomainConfigResponse
Provides cluster configuration information about the specified Elasticsearch domain, such as the state, creation date, update version, and update date for cluster options.
371 |
# File 'sig/client.rbs', line 371
def describe_elasticsearch_domain_config: (
|
#describe_elasticsearch_domains(params = {}) ⇒ Types::DescribeElasticsearchDomainsResponse
Returns domain configuration information about the specified Elasticsearch domains, including the domain ID, domain endpoint, and domain ARN.
381 |
# File 'sig/client.rbs', line 381
def describe_elasticsearch_domains: (
|
#describe_elasticsearch_instance_type_limits(params = {}) ⇒ Types::DescribeElasticsearchInstanceTypeLimitsResponse
Describe Elasticsearch Limits for a given InstanceType and
ElasticsearchVersion. When modifying existing Domain, specify the DomainName to know what Limits are supported for modifying.
391 |
# File 'sig/client.rbs', line 391
def describe_elasticsearch_instance_type_limits: (
|
#describe_inbound_cross_cluster_search_connections(params = {}) ⇒ Types::DescribeInboundCrossClusterSearchConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
404 |
# File 'sig/client.rbs', line 404
def describe_inbound_cross_cluster_search_connections: (
|
#describe_outbound_cross_cluster_search_connections(params = {}) ⇒ Types::DescribeOutboundCrossClusterSearchConnectionsResponse
Lists all the outbound cross-cluster search connections for a source domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
422 |
# File 'sig/client.rbs', line 422
def describe_outbound_cross_cluster_search_connections: (
|
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to Amazon ES. Includes options for filtering, limiting the number of results, and pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
440 |
# File 'sig/client.rbs', line 440
def describe_packages: (
|
#describe_reserved_elasticsearch_instance_offerings(params = {}) ⇒ Types::DescribeReservedElasticsearchInstanceOfferingsResponse
Lists available reserved Elasticsearch instance offerings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
458 |
# File 'sig/client.rbs', line 458
def describe_reserved_elasticsearch_instance_offerings: (
|
#describe_reserved_elasticsearch_instances(params = {}) ⇒ Types::DescribeReservedElasticsearchInstancesResponse
Returns information about reserved Elasticsearch instances for this account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
471 |
# File 'sig/client.rbs', line 471
def describe_reserved_elasticsearch_instances: (
|
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
484 |
# File 'sig/client.rbs', line 484
def describe_vpc_endpoints: (
|
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Dissociates a package from the Amazon ES domain.
494 |
# File 'sig/client.rbs', line 494
def dissociate_package: (
|
#get_compatible_elasticsearch_versions(params = {}) ⇒ Types::GetCompatibleElasticsearchVersionsResponse
Returns a list of upgrade compatible Elastisearch versions. You can
optionally pass a DomainName to get all upgrade compatible
Elasticsearch versions for that specific domain.
505 |
# File 'sig/client.rbs', line 505
def get_compatible_elasticsearch_versions: (
|
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of versions of the package, along with their creation time and commit message.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
517 |
# File 'sig/client.rbs', line 517
def get_package_version_history: (
|
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades that were performed on the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
530 |
# File 'sig/client.rbs', line 530
def get_upgrade_history: (
|
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.
544 |
# File 'sig/client.rbs', line 544
def get_upgrade_status: (
|
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the name of all Elasticsearch domains owned by the current user's account.
554 |
# File 'sig/client.rbs', line 554
def list_domain_names: (
|
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon ES domains associated with the package.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
565 |
# File 'sig/client.rbs', line 565
def list_domains_for_package: (
|
#list_elasticsearch_instance_types(params = {}) ⇒ Types::ListElasticsearchInstanceTypesResponse
List all Elasticsearch instance types that are supported for given ElasticsearchVersion
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
578 |
# File 'sig/client.rbs', line 578
def list_elasticsearch_instance_types: (
|
#list_elasticsearch_versions(params = {}) ⇒ Types::ListElasticsearchVersionsResponse
List all supported Elasticsearch versions
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
592 |
# File 'sig/client.rbs', line 592
def list_elasticsearch_versions: (
|
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with the Amazon ES domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
604 |
# File 'sig/client.rbs', line 604
def list_packages_for_domain: (
|
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all tags for the given Elasticsearch domain.
616 |
# File 'sig/client.rbs', line 616
def list_tags: (
|
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
627 |
# File 'sig/client.rbs', line 627
def list_vpc_endpoint_access: (
|
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current account and Region.
639 |
# File 'sig/client.rbs', line 639
def list_vpc_endpoints: (
|
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
650 |
# File 'sig/client.rbs', line 650
def list_vpc_endpoints_for_domain: (
|
#purchase_reserved_elasticsearch_instance_offering(params = {}) ⇒ Types::PurchaseReservedElasticsearchInstanceOfferingResponse
Allows you to purchase reserved Elasticsearch instances.
662 |
# File 'sig/client.rbs', line 662
def purchase_reserved_elasticsearch_instance_offering: (
|
#reject_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::RejectInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to reject an inbound cross-cluster search connection request.
674 |
# File 'sig/client.rbs', line 674
def reject_inbound_cross_cluster_search_connection: (
|
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from the specified Elasticsearch domain.
680 |
# File 'sig/client.rbs', line 680
def remove_tags: (
|
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
690 |
# File 'sig/client.rbs', line 690
def revoke_vpc_endpoint_access: (
|
#start_elasticsearch_service_software_update(params = {}) ⇒ Types::StartElasticsearchServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon ES domain.
701 |
# File 'sig/client.rbs', line 701
def start_elasticsearch_service_software_update: (
|
#update_elasticsearch_domain_config(params = {}) ⇒ Types::UpdateElasticsearchDomainConfigResponse
Modifies the cluster configuration of the specified Elasticsearch domain, setting as setting the instance type and the number of instances.
712 |
# File 'sig/client.rbs', line 712
def update_elasticsearch_domain_config: (
|
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon ES domains.
782 |
# File 'sig/client.rbs', line 782
def update_package: (
|
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
798 |
# File 'sig/client.rbs', line 798
def update_vpc_endpoint: (
|
#upgrade_elasticsearch_domain(params = {}) ⇒ Types::UpgradeElasticsearchDomainResponse
Allows you to either upgrade your domain or perform an Upgrade eligibility check to a compatible Elasticsearch version.
815 |
# File 'sig/client.rbs', line 815
def upgrade_elasticsearch_domain: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3666 3667 3668 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3666 def waiter_names [] end |