Class: Aws::ElasticsearchService::Types::AdditionalLimit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticsearchservice/types.rb

Overview

List of limits that are specific to a given InstanceType and for each of it's InstanceRole .

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#limit_nameString

Name of Additional Limit is specific to a given InstanceType and for each of it's InstanceRole etc. Attributes and their details:

  • MaximumNumberOfDataNodesSupported ESPartitionInstanceType* MaximumNumberOfDataNodesWithoutMasterNode ESPartitionInstanceType

Returns:

  • (String)


105
106
107
108
109
110
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 105

class AdditionalLimit < Struct.new(
  :limit_name,
  :limit_values)
  SENSITIVE = []
  include Aws::Structure
end

#limit_valuesArray<String>

Value for given AdditionalLimit$LimitName .

Returns:

  • (Array<String>)


105
106
107
108
109
110
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 105

class AdditionalLimit < Struct.new(
  :limit_name,
  :limit_values)
  SENSITIVE = []
  include Aws::Structure
end