Class: Aws::ElasticsearchService::Types::CreateElasticsearchDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::CreateElasticsearchDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_policies ⇒ String
IAM access policy as a JSON-formatted string.
-
#advanced_options ⇒ Hash<String,String>
Option to allow references to indices in an HTTP request body.
-
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsInput
Specifies advanced security options.
-
#auto_tune_options ⇒ Types::AutoTuneOptionsInput
Specifies Auto-Tune options.
-
#automated_snapshot_pause_options ⇒ Types::AutomatedSnapshotPauseRequestOptions
Specifies the automated snapshot pause options for the domain.
-
#cognito_options ⇒ Types::CognitoOptions
Options to specify the Cognito user and identity pools for Kibana authentication.
-
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptions
Specifies the deployment strategy options.
-
#domain_endpoint_options ⇒ Types::DomainEndpointOptions
Options to specify configuration that will be applied to the domain endpoint.
-
#domain_name ⇒ String
The name of the Elasticsearch domain that you are creating.
-
#ebs_options ⇒ Types::EBSOptions
Options to enable, disable and specify the type and size of EBS storage volumes.
-
#elasticsearch_cluster_config ⇒ Types::ElasticsearchClusterConfig
Configuration options for an Elasticsearch domain.
-
#elasticsearch_version ⇒ String
String of format X.Y to specify version for the Elasticsearch domain eg.
-
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptions
Specifies the Encryption At Rest Options.
-
#log_publishing_options ⇒ Hash<String,Types::LogPublishingOption>
Map of ‘LogType` and `LogPublishingOption`, each containing options to publish a given type of Elasticsearch log.
-
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptions
Specifies the NodeToNodeEncryptionOptions.
-
#snapshot_options ⇒ Types::SnapshotOptions
Option to set time, in UTC format, of the daily automated snapshot.
-
#tag_list ⇒ Array<Types::Tag>
A list of ‘Tag` added during domain creation.
-
#vpc_options ⇒ Types::VPCOptions
Options to specify the subnets and security groups for VPC endpoint.
Instance Attribute Details
#access_policies ⇒ String
IAM access policy as a JSON-formatted string.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#advanced_options ⇒ Hash<String,String>
Option to allow references to indices in an HTTP request body. Must be ‘false` when configuring access to individual sub-resources. By default, the value is `true`. See [Configuration Advanced Options] for more information.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsInput
Specifies advanced security options.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#auto_tune_options ⇒ Types::AutoTuneOptionsInput
Specifies Auto-Tune options.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#automated_snapshot_pause_options ⇒ Types::AutomatedSnapshotPauseRequestOptions
Specifies the automated snapshot pause options for the domain.
Suspending snapshots reduces data protection. You cannot restore your domain to points in time when snapshots are suspended. Use this feature only for short-term operational needs such as migrations or maintenance windows.
Maximum suspension duration: 3 days.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#cognito_options ⇒ Types::CognitoOptions
Options to specify the Cognito user and identity pools for Kibana authentication. For more information, see [Amazon Cognito Authentication for Kibana].
[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-cognito-auth.html
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptions
Specifies the deployment strategy options.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#domain_endpoint_options ⇒ Types::DomainEndpointOptions
Options to specify configuration that will be applied to the domain endpoint.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the Elasticsearch domain that you are creating. Domain names are unique across the domains owned by an account within an AWS region. Domain names must start with a lowercase letter and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#ebs_options ⇒ Types::EBSOptions
Options to enable, disable and specify the type and size of EBS storage volumes.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_cluster_config ⇒ Types::ElasticsearchClusterConfig
Configuration options for an Elasticsearch domain. Specifies the instance type and number of instances in the domain cluster.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_version ⇒ String
String of format X.Y to specify version for the Elasticsearch domain eg. “1.5” or “2.3”. For more information, see [Creating Elasticsearch Domains] in the *Amazon Elasticsearch Service Developer Guide*.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptions
Specifies the Encryption At Rest Options.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#log_publishing_options ⇒ Hash<String,Types::LogPublishingOption>
Map of ‘LogType` and `LogPublishingOption`, each containing options to publish a given type of Elasticsearch log.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptions
Specifies the NodeToNodeEncryptionOptions.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#snapshot_options ⇒ Types::SnapshotOptions
Option to set time, in UTC format, of the daily automated snapshot. Default value is 0 hours.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#tag_list ⇒ Array<Types::Tag>
A list of ‘Tag` added during domain creation.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#vpc_options ⇒ Types::VPCOptions
Options to specify the subnets and security groups for VPC endpoint. For more information, see [Creating a VPC] in *VPC Endpoints for Amazon Elasticsearch Service Domains*
[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html#es-creating-vpc
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1055 class CreateElasticsearchDomainRequest < Struct.new( :domain_name, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :tag_list, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |