Class: Aws::ElasticsearchService::Types::CreateOutboundCrossClusterSearchConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::CreateOutboundCrossClusterSearchConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for the parameters to the CreateOutboundCrossClusterSearchConnection operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_alias ⇒ String
Specifies the connection alias that will be used by the customer for this connection.
-
#destination_domain_info ⇒ Types::DomainInformation
Specifies the
DomainInformationfor the destination Elasticsearch domain. -
#source_domain_info ⇒ Types::DomainInformation
Specifies the
DomainInformationfor the source Elasticsearch domain.
Instance Attribute Details
#connection_alias ⇒ String
Specifies the connection alias that will be used by the customer for this connection.
1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1015 class CreateOutboundCrossClusterSearchConnectionRequest < Struct.new( :source_domain_info, :destination_domain_info, :connection_alias) SENSITIVE = [] include Aws::Structure end |
#destination_domain_info ⇒ Types::DomainInformation
Specifies the DomainInformation for the destination Elasticsearch domain.
1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1015 class CreateOutboundCrossClusterSearchConnectionRequest < Struct.new( :source_domain_info, :destination_domain_info, :connection_alias) SENSITIVE = [] include Aws::Structure end |
#source_domain_info ⇒ Types::DomainInformation
Specifies the DomainInformation for the source Elasticsearch domain.
1015 1016 1017 1018 1019 1020 1021 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1015 class CreateOutboundCrossClusterSearchConnectionRequest < Struct.new( :source_domain_info, :destination_domain_info, :connection_alias) SENSITIVE = [] include Aws::Structure end |