Class: Aws::ElasticsearchService::Types::CreateOutboundCrossClusterSearchConnectionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::CreateOutboundCrossClusterSearchConnectionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
The result of a CreateOutboundCrossClusterSearchConnection request. Contains the details of the newly created cross-cluster search connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_alias ⇒ String
Specifies the connection alias provided during the create connection request.
-
#connection_status ⇒ Types::OutboundCrossClusterSearchConnectionStatus
Specifies the
OutboundCrossClusterSearchConnectionStatusfor the newly created connection. -
#cross_cluster_search_connection_id ⇒ String
Unique id for the created outbound connection, which is used for subsequent operations on connection.
-
#destination_domain_info ⇒ Types::DomainInformation
Specifies the
DomainInformationfor the destination Elasticsearch domain. -
#source_domain_info ⇒ Types::DomainInformation
Specifies the
DomainInformationfor the source Elasticsearch domain.
Instance Attribute Details
#connection_alias ⇒ String
Specifies the connection alias provided during the create connection request.
1052 1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1052 class CreateOutboundCrossClusterSearchConnectionResponse < Struct.new( :source_domain_info, :destination_domain_info, :connection_alias, :connection_status, :cross_cluster_search_connection_id) SENSITIVE = [] include Aws::Structure end |
#connection_status ⇒ Types::OutboundCrossClusterSearchConnectionStatus
Specifies the OutboundCrossClusterSearchConnectionStatus for the newly created connection.
1052 1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1052 class CreateOutboundCrossClusterSearchConnectionResponse < Struct.new( :source_domain_info, :destination_domain_info, :connection_alias, :connection_status, :cross_cluster_search_connection_id) SENSITIVE = [] include Aws::Structure end |
#cross_cluster_search_connection_id ⇒ String
Unique id for the created outbound connection, which is used for subsequent operations on connection.
1052 1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1052 class CreateOutboundCrossClusterSearchConnectionResponse < Struct.new( :source_domain_info, :destination_domain_info, :connection_alias, :connection_status, :cross_cluster_search_connection_id) SENSITIVE = [] include Aws::Structure end |
#destination_domain_info ⇒ Types::DomainInformation
Specifies the DomainInformation for the destination Elasticsearch domain.
1052 1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1052 class CreateOutboundCrossClusterSearchConnectionResponse < Struct.new( :source_domain_info, :destination_domain_info, :connection_alias, :connection_status, :cross_cluster_search_connection_id) SENSITIVE = [] include Aws::Structure end |
#source_domain_info ⇒ Types::DomainInformation
Specifies the DomainInformation for the source Elasticsearch domain.
1052 1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1052 class CreateOutboundCrossClusterSearchConnectionResponse < Struct.new( :source_domain_info, :destination_domain_info, :connection_alias, :connection_status, :cross_cluster_search_connection_id) SENSITIVE = [] include Aws::Structure end |