Class: Aws::ElasticsearchService::Types::CreateVpcEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::CreateVpcEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for the parameters to the CreateVpcEndpointRequest operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
-
#domain_arn ⇒ String
The Amazon Resource Name (ARN) of the domain to grant access to.
-
#vpc_options ⇒ Types::VPCOptions
Options to specify the subnets and security groups for the endpoint.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
1117 1118 1119 1120 1121 1122 1123 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1117 class CreateVpcEndpointRequest < Struct.new( :domain_arn, :vpc_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#domain_arn ⇒ String
The Amazon Resource Name (ARN) of the domain to grant access to.
1117 1118 1119 1120 1121 1122 1123 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1117 class CreateVpcEndpointRequest < Struct.new( :domain_arn, :vpc_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#vpc_options ⇒ Types::VPCOptions
Options to specify the subnets and security groups for the endpoint.
1117 1118 1119 1120 1121 1122 1123 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1117 class CreateVpcEndpointRequest < Struct.new( :domain_arn, :vpc_options, :client_token) SENSITIVE = [] include Aws::Structure end |