Class: Aws::ElasticsearchService::Types::DeleteInboundCrossClusterSearchConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::DeleteInboundCrossClusterSearchConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for the parameters to the
DeleteInboundCrossClusterSearchConnection operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cross_cluster_search_connection_id ⇒ String
The id of the inbound connection that you want to permanently delete.
Instance Attribute Details
#cross_cluster_search_connection_id ⇒ String
The id of the inbound connection that you want to permanently delete.
1282 1283 1284 1285 1286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1282 class DeleteInboundCrossClusterSearchConnectionRequest < Struct.new( :cross_cluster_search_connection_id) SENSITIVE = [] include Aws::Structure end |