Class: Aws::ElasticsearchService::Types::DeleteVpcEndpointResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::DeleteVpcEndpointResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for response parameters to the DeleteVpcEndpoint
operation. Contains the summarized detail of the VPC Endpoint being
deleted.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#vpc_endpoint_summary ⇒ Types::VpcEndpointSummary
Information about the deleted endpoint, including its current status (
DELETINGorDELETE_FAILED).
Instance Attribute Details
#vpc_endpoint_summary ⇒ Types::VpcEndpointSummary
Information about the deleted endpoint, including its current status
(DELETING or DELETE_FAILED).
1376 1377 1378 1379 1380 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1376 class DeleteVpcEndpointResponse < Struct.new( :vpc_endpoint_summary) SENSITIVE = [] include Aws::Structure end |