Class: Aws::ElasticsearchService::Types::DeploymentStrategyOptionsStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticsearchservice/types.rb

Overview

Specifies the status of deployment strategy options for the specified Elasticsearch domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#optionsTypes::DeploymentStrategyOptions

Specifies deployment strategy options for the specified Elasticsearch domain.



1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1302

class DeploymentStrategyOptionsStatus < Struct.new(
  :options,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::OptionStatus

Specifies the status of the deployment strategy options for the specified Elasticsearch domain.

Returns:



1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1302

class DeploymentStrategyOptionsStatus < Struct.new(
  :options,
  :status)
  SENSITIVE = []
  include Aws::Structure
end