Class: Aws::ElasticsearchService::Types::DescribeElasticsearchInstanceTypeLimitsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::DescribeElasticsearchInstanceTypeLimitsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for the parameters to DescribeElasticsearchInstanceTypeLimits operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
DomainName represents the name of the Domain that we are trying to modify.
-
#elasticsearch_version ⇒ String
Version of Elasticsearch for which
Limitsare needed. -
#instance_type ⇒ String
The instance type for an Elasticsearch cluster for which Elasticsearch
Limitsare needed.
Instance Attribute Details
#domain_name ⇒ String
DomainName represents the name of the Domain that we are trying to
modify. This should be present only if we are querying for
Elasticsearch Limits for existing domain.
1603 1604 1605 1606 1607 1608 1609 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1603 class DescribeElasticsearchInstanceTypeLimitsRequest < Struct.new( :domain_name, :instance_type, :elasticsearch_version) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_version ⇒ String
Version of Elasticsearch for which Limits are needed.
1603 1604 1605 1606 1607 1608 1609 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1603 class DescribeElasticsearchInstanceTypeLimitsRequest < Struct.new( :domain_name, :instance_type, :elasticsearch_version) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type for an Elasticsearch cluster for which
Elasticsearch Limits are needed.
1603 1604 1605 1606 1607 1608 1609 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1603 class DescribeElasticsearchInstanceTypeLimitsRequest < Struct.new( :domain_name, :instance_type, :elasticsearch_version) SENSITIVE = [] include Aws::Structure end |