Class: Aws::ElasticsearchService::Types::DomainEndpointOptionsStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::DomainEndpointOptionsStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
The configured endpoint options for the domain and their current status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#options ⇒ Types::DomainEndpointOptions
Options to configure endpoint for the Elasticsearch domain.
-
#status ⇒ Types::OptionStatus
The status of the endpoint options for the Elasticsearch domain.
Instance Attribute Details
#options ⇒ Types::DomainEndpointOptions
Options to configure endpoint for the Elasticsearch domain.
2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2005 class DomainEndpointOptionsStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OptionStatus
The status of the endpoint options for the Elasticsearch domain. See
OptionStatus for the status information that's included.
2005 2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2005 class DomainEndpointOptionsStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |