Class: Aws::ElasticsearchService::Types::Duration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::Duration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Specifies maintenance schedule duration: duration value and duration unit. See the Developer Guide for more information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unit ⇒ String
Specifies the unit of a maintenance schedule duration.
-
#value ⇒ Integer
Integer to specify the value of a maintenance schedule duration.
Instance Attribute Details
#unit ⇒ String
Specifies the unit of a maintenance schedule duration. Valid value is HOURS. See the Developer Guide for more information.
2149 2150 2151 2152 2153 2154 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2149 class Duration < Struct.new( :value, :unit) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Integer
Integer to specify the value of a maintenance schedule duration. See the Developer Guide for more information.
2149 2150 2151 2152 2153 2154 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2149 class Duration < Struct.new( :value, :unit) SENSITIVE = [] include Aws::Structure end |