Class: Aws::ElasticsearchService::Types::ElasticsearchClusterConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::ElasticsearchClusterConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Specifies the configuration for the domain cluster, such as the type and number of instances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cold_storage_options ⇒ Types::ColdStorageOptions
Specifies the
ColdStorageOptionsconfig for Elasticsearch Domain. -
#dedicated_master_count ⇒ Integer
Total number of dedicated master nodes, active and on standby, for the cluster.
-
#dedicated_master_enabled ⇒ Boolean
A boolean value to indicate whether a dedicated master node is enabled.
-
#dedicated_master_type ⇒ String
The instance type for a dedicated master node.
-
#instance_count ⇒ Integer
The number of instances in the specified domain cluster.
-
#instance_type ⇒ String
The instance type for an Elasticsearch cluster.
-
#warm_count ⇒ Integer
The number of warm nodes in the cluster.
-
#warm_enabled ⇒ Boolean
True to enable warm storage.
-
#warm_type ⇒ String
The instance type for the Elasticsearch cluster's warm nodes.
-
#zone_awareness_config ⇒ Types::ZoneAwarenessConfig
Specifies the zone awareness configuration for a domain when zone awareness is enabled.
-
#zone_awareness_enabled ⇒ Boolean
A boolean value to indicate whether zone awareness is enabled.
Instance Attribute Details
#cold_storage_options ⇒ Types::ColdStorageOptions
Specifies the ColdStorageOptions config for Elasticsearch Domain
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#dedicated_master_count ⇒ Integer
Total number of dedicated master nodes, active and on standby, for the cluster.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#dedicated_master_enabled ⇒ Boolean
A boolean value to indicate whether a dedicated master node is enabled. See About Dedicated Master Nodes for more information.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#dedicated_master_type ⇒ String
The instance type for a dedicated master node.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of instances in the specified domain cluster.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type for an Elasticsearch cluster. UltraWarm instance types are not supported for data instances.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#warm_count ⇒ Integer
The number of warm nodes in the cluster.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#warm_enabled ⇒ Boolean
True to enable warm storage.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#warm_type ⇒ String
The instance type for the Elasticsearch cluster's warm nodes.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#zone_awareness_config ⇒ Types::ZoneAwarenessConfig
Specifies the zone awareness configuration for a domain when zone awareness is enabled.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#zone_awareness_enabled ⇒ Boolean
A boolean value to indicate whether zone awareness is enabled. See About Zone Awareness for more information.
2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2272 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |