Class: Aws::ElasticsearchService::Types::ElasticsearchDomainConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::ElasticsearchDomainConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
The configuration of an Elasticsearch domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_policies ⇒ Types::AccessPoliciesStatus
IAM access policy as a JSON-formatted string.
-
#advanced_options ⇒ Types::AdvancedOptionsStatus
Specifies the ‘AdvancedOptions` for the domain.
-
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsStatus
Specifies ‘AdvancedSecurityOptions` for the domain.
-
#auto_tune_options ⇒ Types::AutoTuneOptionsStatus
Specifies ‘AutoTuneOptions` for the domain.
-
#automated_snapshot_pause_options ⇒ Types::AutomatedSnapshotPauseOptionsStatus
Specifies ‘AutomatedSnapshotPauseOptions` for the domain.
-
#change_progress_details ⇒ Types::ChangeProgressDetails
Specifies change details of the domain configuration change.
-
#cognito_options ⇒ Types::CognitoOptionsStatus
The ‘CognitoOptions` for the specified domain.
-
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptionsStatus
Specifies ‘DeploymentStrategyOptions` for the domain.
-
#domain_endpoint_options ⇒ Types::DomainEndpointOptionsStatus
Specifies the ‘DomainEndpointOptions` for the Elasticsearch domain.
-
#ebs_options ⇒ Types::EBSOptionsStatus
Specifies the ‘EBSOptions` for the Elasticsearch domain.
-
#elasticsearch_cluster_config ⇒ Types::ElasticsearchClusterConfigStatus
Specifies the ‘ElasticsearchClusterConfig` for the Elasticsearch domain.
-
#elasticsearch_version ⇒ Types::ElasticsearchVersionStatus
String of format X.Y to specify version for the Elasticsearch domain.
-
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptionsStatus
Specifies the ‘EncryptionAtRestOptions` for the Elasticsearch domain.
-
#log_publishing_options ⇒ Types::LogPublishingOptionsStatus
Log publishing options for the given domain.
-
#modifying_properties ⇒ Array<Types::ModifyingProperties>
Information about the domain properties that are currently being modified.
-
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptionsStatus
Specifies the ‘NodeToNodeEncryptionOptions` for the Elasticsearch domain.
-
#snapshot_options ⇒ Types::SnapshotOptionsStatus
Specifies the ‘SnapshotOptions` for the Elasticsearch domain.
-
#vpc_options ⇒ Types::VPCDerivedInfoStatus
The ‘VPCOptions` for the specified domain.
Instance Attribute Details
#access_policies ⇒ Types::AccessPoliciesStatus
IAM access policy as a JSON-formatted string.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#advanced_options ⇒ Types::AdvancedOptionsStatus
Specifies the ‘AdvancedOptions` for the domain. See [Configuring Advanced Options] for more information.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsStatus
Specifies ‘AdvancedSecurityOptions` for the domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#auto_tune_options ⇒ Types::AutoTuneOptionsStatus
Specifies ‘AutoTuneOptions` for the domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#automated_snapshot_pause_options ⇒ Types::AutomatedSnapshotPauseOptionsStatus
Specifies ‘AutomatedSnapshotPauseOptions` for the domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#change_progress_details ⇒ Types::ChangeProgressDetails
Specifies change details of the domain configuration change.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#cognito_options ⇒ Types::CognitoOptionsStatus
The ‘CognitoOptions` for the specified domain. For more information, see [Amazon Cognito Authentication for Kibana].
[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-cognito-auth.html
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptionsStatus
Specifies ‘DeploymentStrategyOptions` for the domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#domain_endpoint_options ⇒ Types::DomainEndpointOptionsStatus
Specifies the ‘DomainEndpointOptions` for the Elasticsearch domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#ebs_options ⇒ Types::EBSOptionsStatus
Specifies the ‘EBSOptions` for the Elasticsearch domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_cluster_config ⇒ Types::ElasticsearchClusterConfigStatus
Specifies the ‘ElasticsearchClusterConfig` for the Elasticsearch domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_version ⇒ Types::ElasticsearchVersionStatus
String of format X.Y to specify version for the Elasticsearch domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptionsStatus
Specifies the ‘EncryptionAtRestOptions` for the Elasticsearch domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#log_publishing_options ⇒ Types::LogPublishingOptionsStatus
Log publishing options for the given domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#modifying_properties ⇒ Array<Types::ModifyingProperties>
Information about the domain properties that are currently being modified.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptionsStatus
Specifies the ‘NodeToNodeEncryptionOptions` for the Elasticsearch domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#snapshot_options ⇒ Types::SnapshotOptionsStatus
Specifies the ‘SnapshotOptions` for the Elasticsearch domain.
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#vpc_options ⇒ Types::VPCDerivedInfoStatus
The ‘VPCOptions` for the specified domain. For more information, see [VPC Endpoints for Amazon Elasticsearch Service Domains].
[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html
2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2390 class ElasticsearchDomainConfig < Struct.new( :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |