Class: Aws::ElasticsearchService::Types::ElasticsearchDomainStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticsearchservice/types.rb

Overview

The current status of an Elasticsearch domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_policiesString

IAM access policy as a JSON-formatted string.

Returns:

  • (String)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#advanced_optionsHash<String,String>

Specifies the status of the AdvancedOptions

Returns:

  • (Hash<String,String>)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#advanced_security_optionsTypes::AdvancedSecurityOptions

The current status of the Elasticsearch domain's advanced security options.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon resource name (ARN) of an Elasticsearch domain. See Identifiers for IAM Entities in Using AWS Identity and Access Management for more information.

Returns:

  • (String)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#auto_tune_optionsTypes::AutoTuneOptionsOutput

The current status of the Elasticsearch domain's Auto-Tune options.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#automated_snapshot_pause_optionsTypes::AutomatedSnapshotPauseOptions

The current status of the Elasticsearch domain's automated snapshot pause options.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#change_progress_detailsTypes::ChangeProgressDetails

Specifies change details of the domain configuration change.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#cognito_optionsTypes::CognitoOptions

The CognitoOptions for the specified domain. For more information, see Amazon Cognito Authentication for Kibana.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#createdBoolean

The domain creation status. True if the creation of an Elasticsearch domain is complete. False if domain creation is still in progress.

Returns:

  • (Boolean)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#deletedBoolean

The domain deletion status. True if a delete request has been received for the domain but resource cleanup is still in progress. False if the domain has not been deleted. Once domain deletion is complete, the status of the domain is no longer returned.

Returns:

  • (Boolean)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_strategy_optionsTypes::DeploymentStrategyOptions

The current status of the Elasticsearch domain's deployment strategy options.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#domain_endpoint_optionsTypes::DomainEndpointOptions

The current status of the Elasticsearch domain's endpoint options.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The unique identifier for the specified Elasticsearch domain.

Returns:

  • (String)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

Returns:

  • (String)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#domain_processing_statusString

The status of any changes that are currently in progress for the domain.

Returns:

  • (String)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_optionsTypes::EBSOptions

The EBSOptions for the specified domain. See Configuring EBS-based Storage for more information.

Returns:



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#elasticsearch_cluster_configTypes::ElasticsearchClusterConfig

The type and number of instances in the domain cluster.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#elasticsearch_versionString

Returns:

  • (String)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_at_rest_optionsTypes::EncryptionAtRestOptions

Specifies the status of the EncryptionAtRestOptions.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The Elasticsearch domain endpoint that you use to submit index and search requests.

Returns:

  • (String)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#endpointsHash<String,String>

Map containing the Elasticsearch domain endpoints used to submit index and search requests. Example key, value: 'vpc','vpc-endpoint-h2dsd34efgyghrtguk5gt6j2foh4.us-east-1.es.amazonaws.com'.

Returns:

  • (Hash<String,String>)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#engine_modeString

The engine mode for the domain.

Returns:

  • (String)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#log_publishing_optionsHash<String,Types::LogPublishingOption>

Log publishing options for the given domain.

Returns:



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#modifying_propertiesArray<Types::ModifyingProperties>

Information about the domain properties that are currently being modified.

Returns:



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#node_to_node_encryption_optionsTypes::NodeToNodeEncryptionOptions

Specifies the status of the NodeToNodeEncryptionOptions.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#processingBoolean

The status of the Elasticsearch domain configuration. True if Amazon Elasticsearch Service is processing configuration changes. False if the configuration is active.

Returns:

  • (Boolean)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#service_software_optionsTypes::ServiceSoftwareOptions

The current status of the Elasticsearch domain's service software.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_optionsTypes::SnapshotOptions

Specifies the status of the SnapshotOptions



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#upgrade_processingBoolean

The status of an Elasticsearch domain version upgrade. True if Amazon Elasticsearch Service is undergoing a version upgrade. False if the configuration is active.

Returns:

  • (Boolean)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#use_caseString

The primary use case for the domain.

Returns:

  • (String)


2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_optionsTypes::VPCDerivedInfo

The VPCOptions for the specified domain. For more information, see VPC Endpoints for Amazon Elasticsearch Service Domains.



2601
2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
2612
2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2601

class ElasticsearchDomainStatus < Struct.new(
  :domain_id,
  :domain_name,
  :arn,
  :created,
  :deleted,
  :endpoint,
  :endpoints,
  :processing,
  :upgrade_processing,
  :elasticsearch_version,
  :elasticsearch_cluster_config,
  :ebs_options,
  :access_policies,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :encryption_at_rest_options,
  :node_to_node_encryption_options,
  :advanced_options,
  :log_publishing_options,
  :service_software_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :auto_tune_options,
  :change_progress_details,
  :domain_processing_status,
  :modifying_properties,
  :deployment_strategy_options,
  :automated_snapshot_pause_options,
  :use_case,
  :engine_mode)
  SENSITIVE = []
  include Aws::Structure
end