Class: Aws::ElasticsearchService::Types::EngineModeStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::EngineModeStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
The status of the engine mode for the domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#options ⇒ String
The engine mode configured for the domain.
-
#status ⇒ Types::OptionStatus
The current status of the engine mode for the domain.
Instance Attribute Details
#options ⇒ String
The engine mode configured for the domain.
2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2704 class EngineModeStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OptionStatus
The current status of the engine mode for the domain.
2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2704 class EngineModeStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |