Class: Aws::ElasticsearchService::Types::ListPackagesForDomainResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::ListPackagesForDomainResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for response parameters to ‘ ListPackagesForDomain ` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_package_details_list ⇒ Array<Types::DomainPackageDetails>
List of
DomainPackageDetailsobjects. -
#next_token ⇒ String
Pagination token that needs to be supplied to the next call to get the next page of results.
Instance Attribute Details
#domain_package_details_list ⇒ Array<Types::DomainPackageDetails>
List of DomainPackageDetails objects.
3107 3108 3109 3110 3111 3112 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3107 class ListPackagesForDomainResponse < Struct.new( :domain_package_details_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Pagination token that needs to be supplied to the next call to get the next page of results.
3107 3108 3109 3110 3111 3112 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3107 class ListPackagesForDomainResponse < Struct.new( :domain_package_details_list, :next_token) SENSITIVE = [] include Aws::Structure end |