Class: Aws::ElasticsearchService::Types::LogPublishingOptionsStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::LogPublishingOptionsStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
The configured log publishing options for the domain and their current status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#options ⇒ Hash<String,Types::LogPublishingOption>
The log publishing options configured for the Elasticsearch domain.
-
#status ⇒ Types::OptionStatus
The status of the log publishing options for the Elasticsearch domain.
Instance Attribute Details
#options ⇒ Hash<String,Types::LogPublishingOption>
The log publishing options configured for the Elasticsearch domain.
3440 3441 3442 3443 3444 3445 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3440 class LogPublishingOptionsStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OptionStatus
The status of the log publishing options for the Elasticsearch
domain. See OptionStatus for the status information that's
included.
3440 3441 3442 3443 3444 3445 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3440 class LogPublishingOptionsStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |