Class: Aws::ElasticsearchService::Types::OptionStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::OptionStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Provides the current status of the entity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
Timestamp which tells the creation date for the entity.
-
#pending_deletion ⇒ Boolean
Indicates whether the Elasticsearch domain is being deleted.
-
#state ⇒ String
Provides the
OptionStatefor the Elasticsearch domain. -
#update_date ⇒ Time
Timestamp which tells the last updated time for the entity.
-
#update_version ⇒ Integer
Specifies the latest version for the entity.
Instance Attribute Details
#creation_date ⇒ Time
Timestamp which tells the creation date for the entity.
3560 3561 3562 3563 3564 3565 3566 3567 3568 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3560 class OptionStatus < Struct.new( :creation_date, :update_date, :update_version, :state, :pending_deletion) SENSITIVE = [] include Aws::Structure end |
#pending_deletion ⇒ Boolean
Indicates whether the Elasticsearch domain is being deleted.
3560 3561 3562 3563 3564 3565 3566 3567 3568 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3560 class OptionStatus < Struct.new( :creation_date, :update_date, :update_version, :state, :pending_deletion) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Provides the OptionState for the Elasticsearch domain.
3560 3561 3562 3563 3564 3565 3566 3567 3568 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3560 class OptionStatus < Struct.new( :creation_date, :update_date, :update_version, :state, :pending_deletion) SENSITIVE = [] include Aws::Structure end |
#update_date ⇒ Time
Timestamp which tells the last updated time for the entity.
3560 3561 3562 3563 3564 3565 3566 3567 3568 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3560 class OptionStatus < Struct.new( :creation_date, :update_date, :update_version, :state, :pending_deletion) SENSITIVE = [] include Aws::Structure end |
#update_version ⇒ Integer
Specifies the latest version for the entity.
3560 3561 3562 3563 3564 3565 3566 3567 3568 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3560 class OptionStatus < Struct.new( :creation_date, :update_date, :update_version, :state, :pending_deletion) SENSITIVE = [] include Aws::Structure end |