Class: Aws::ElasticsearchService::Types::RejectInboundCrossClusterSearchConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::RejectInboundCrossClusterSearchConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for the parameters to the RejectInboundCrossClusterSearchConnection operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cross_cluster_search_connection_id ⇒ String
The id of the inbound connection that you want to reject.
Instance Attribute Details
#cross_cluster_search_connection_id ⇒ String
The id of the inbound connection that you want to reject.
3641 3642 3643 3644 3645 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3641 class RejectInboundCrossClusterSearchConnectionRequest < Struct.new( :cross_cluster_search_connection_id) SENSITIVE = [] include Aws::Structure end |