Class: Aws::ElasticsearchService::Types::ReservedElasticsearchInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::ReservedElasticsearchInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Details of a reserved Elasticsearch instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency code for the reserved Elasticsearch instance offering.
-
#duration ⇒ Integer
The duration, in seconds, for which the Elasticsearch instance is reserved.
-
#elasticsearch_instance_count ⇒ Integer
The number of Elasticsearch instances that have been reserved.
-
#elasticsearch_instance_type ⇒ String
The Elasticsearch instance type offered by the reserved instance offering.
-
#fixed_price ⇒ Float
The upfront fixed charge you will paid to purchase the specific reserved Elasticsearch instance offering.
-
#payment_option ⇒ String
The payment option as defined in the reserved Elasticsearch instance offering.
-
#recurring_charges ⇒ Array<Types::RecurringCharge>
The charge to your account regardless of whether you are creating any domains using the instance offering.
-
#reservation_name ⇒ String
The customer-specified identifier to track this reservation.
-
#reserved_elasticsearch_instance_id ⇒ String
The unique identifier for the reservation.
-
#reserved_elasticsearch_instance_offering_id ⇒ String
The offering identifier.
-
#start_time ⇒ Time
The time the reservation started.
-
#state ⇒ String
The state of the reserved Elasticsearch instance.
-
#usage_price ⇒ Float
The rate you are charged for each hour for the domain that is using this reserved instance.
Instance Attribute Details
#currency_code ⇒ String
The currency code for the reserved Elasticsearch instance offering.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration, in seconds, for which the Elasticsearch instance is reserved.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_instance_count ⇒ Integer
The number of Elasticsearch instances that have been reserved.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_instance_type ⇒ String
The Elasticsearch instance type offered by the reserved instance offering.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#fixed_price ⇒ Float
The upfront fixed charge you will paid to purchase the specific reserved Elasticsearch instance offering.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option as defined in the reserved Elasticsearch instance offering.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#recurring_charges ⇒ Array<Types::RecurringCharge>
The charge to your account regardless of whether you are creating any domains using the instance offering.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#reservation_name ⇒ String
The customer-specified identifier to track this reservation.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#reserved_elasticsearch_instance_id ⇒ String
The unique identifier for the reservation.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#reserved_elasticsearch_instance_offering_id ⇒ String
The offering identifier.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time the reservation started.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the reserved Elasticsearch instance.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |
#usage_price ⇒ Float
The rate you are charged for each hour for the domain that is using this reserved instance.
3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 3898 class ReservedElasticsearchInstance < Struct.new( :reservation_name, :reserved_elasticsearch_instance_id, :reserved_elasticsearch_instance_offering_id, :elasticsearch_instance_type, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :elasticsearch_instance_count, :state, :payment_option, :recurring_charges) SENSITIVE = [] include Aws::Structure end |