Class: Aws::ElasticsearchService::Types::StorageType
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::StorageType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
StorageTypes represents the list of storage related types and their attributes that are available for given InstanceType.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#storage_sub_type_name ⇒ String
SubType of the given storage type.
-
#storage_type_limits ⇒ Array<Types::StorageTypeLimit>
List of limits that are applicable for given storage type.
-
#storage_type_name ⇒ String
Type of the storage.
Instance Attribute Details
#storage_sub_type_name ⇒ String
SubType of the given storage type. List of available sub-storage options: For "instance" storageType we wont have any storageSubType, in case of "ebs" storageType we will have following valid storageSubTypes 1. standard 2. gp2 3. gp3 4. io1
Refer VolumeType for more information regarding above EBS storage
options.
4276 4277 4278 4279 4280 4281 4282 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4276 class StorageType < Struct.new( :storage_type_name, :storage_sub_type_name, :storage_type_limits) SENSITIVE = [] include Aws::Structure end |
#storage_type_limits ⇒ Array<Types::StorageTypeLimit>
List of limits that are applicable for given storage type.
4276 4277 4278 4279 4280 4281 4282 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4276 class StorageType < Struct.new( :storage_type_name, :storage_sub_type_name, :storage_type_limits) SENSITIVE = [] include Aws::Structure end |
#storage_type_name ⇒ String
Type of the storage. List of available storage options: 1. instance 2. ebs
4276 4277 4278 4279 4280 4281 4282 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4276 class StorageType < Struct.new( :storage_type_name, :storage_sub_type_name, :storage_type_limits) SENSITIVE = [] include Aws::Structure end |