Class: Aws::ElasticsearchService::Types::UpdateElasticsearchDomainConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::UpdateElasticsearchDomainConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for the parameters to the UpdateElasticsearchDomain operation. Specifies the type and number of instances in the domain cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_policies ⇒ String
IAM access policy as a JSON-formatted string.
-
#advanced_options ⇒ Hash<String,String>
Modifies the advanced option to allow references to indices in an HTTP request body.
-
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsInput
Specifies advanced security options.
-
#auto_tune_options ⇒ Types::AutoTuneOptions
Specifies Auto-Tune options.
-
#cognito_options ⇒ Types::CognitoOptions
Options to specify the Cognito user and identity pools for Kibana authentication.
-
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptions
Specifies the deployment strategy options.
-
#domain_endpoint_options ⇒ Types::DomainEndpointOptions
Options to specify configuration that will be applied to the domain endpoint.
-
#domain_name ⇒ String
The name of the Elasticsearch domain that you are updating.
-
#dry_run ⇒ Boolean
This flag, when set to True, specifies whether the
UpdateElasticsearchDomainrequest should return the results of validation checks without actually applying the change. -
#ebs_options ⇒ Types::EBSOptions
Specify the type and size of the EBS volume that you want to use.
-
#elasticsearch_cluster_config ⇒ Types::ElasticsearchClusterConfig
The type and number of instances to instantiate for the domain cluster.
-
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptions
Specifies the Encryption At Rest Options.
-
#log_publishing_options ⇒ Hash<String,Types::LogPublishingOption>
Map of
LogTypeandLogPublishingOption, each containing options to publish a given type of Elasticsearch log. -
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptions
Specifies the NodeToNodeEncryptionOptions.
-
#snapshot_options ⇒ Types::SnapshotOptions
Option to set the time, in UTC format, for the daily automated snapshot.
-
#vpc_options ⇒ Types::VPCOptions
Options to specify the subnets and security groups for VPC endpoint.
Instance Attribute Details
#access_policies ⇒ String
IAM access policy as a JSON-formatted string.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#advanced_options ⇒ Hash<String,String>
Modifies the advanced option to allow references to indices in an HTTP request body. Must be false when configuring access to individual sub-resources. By default, the value is true. See
- Configuration Advanced Options][1
-
for more information.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#advanced_security_options ⇒ Types::AdvancedSecurityOptionsInput
Specifies advanced security options.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#auto_tune_options ⇒ Types::AutoTuneOptions
Specifies Auto-Tune options.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#cognito_options ⇒ Types::CognitoOptions
Options to specify the Cognito user and identity pools for Kibana authentication. For more information, see [Amazon Cognito Authentication for Kibana].
[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-cognito-auth.html
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptions
Specifies the deployment strategy options.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#domain_endpoint_options ⇒ Types::DomainEndpointOptions
Options to specify configuration that will be applied to the domain endpoint.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the Elasticsearch domain that you are updating.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
This flag, when set to True, specifies whether the UpdateElasticsearchDomain request should return the results of validation checks without actually applying the change. This flag, when set to True, specifies the deployment mechanism through which the update shall be applied on the domain. This will not actually perform the Update.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#ebs_options ⇒ Types::EBSOptions
Specify the type and size of the EBS volume that you want to use.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_cluster_config ⇒ Types::ElasticsearchClusterConfig
The type and number of instances to instantiate for the domain cluster.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptions
Specifies the Encryption At Rest Options.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#log_publishing_options ⇒ Hash<String,Types::LogPublishingOption>
Map of LogType and LogPublishingOption, each containing options to publish a given type of Elasticsearch log.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptions
Specifies the NodeToNodeEncryptionOptions.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#snapshot_options ⇒ Types::SnapshotOptions
Option to set the time, in UTC format, for the daily automated snapshot. Default value is 0 hours.
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |
#vpc_options ⇒ Types::VPCOptions
Options to specify the subnets and security groups for VPC endpoint. For more information, see [Creating a VPC] in *VPC Endpoints for Amazon Elasticsearch Service Domains*
[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html#es-creating-vpc
4269 4270 4271 4272 4273 4274 4275 4276 4277 4278 4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4269 class UpdateElasticsearchDomainConfigRequest < Struct.new( :domain_name, :elasticsearch_cluster_config, :ebs_options, :snapshot_options, :vpc_options, :cognito_options, :advanced_options, :access_policies, :log_publishing_options, :domain_endpoint_options, :advanced_security_options, :node_to_node_encryption_options, :encryption_at_rest_options, :auto_tune_options, :dry_run, :deployment_strategy_options) SENSITIVE = [] include Aws::Structure end |