Class: Aws::ElasticsearchService::Types::UpdatePackageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::UpdatePackageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for request parameters to ‘ UpdatePackage ` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#commit_message ⇒ String
An info message for the new version which will be shown as part of
GetPackageVersionHistoryResponse. -
#package_description ⇒ String
New description of the package.
-
#package_id ⇒ String
Unique identifier for the package.
-
#package_source ⇒ Types::PackageSource
The S3 location for importing the package specified as
S3BucketNameandS3Key.
Instance Attribute Details
#commit_message ⇒ String
An info message for the new version which will be shown as part of GetPackageVersionHistoryResponse.
4328 4329 4330 4331 4332 4333 4334 4335 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4328 class UpdatePackageRequest < Struct.new( :package_id, :package_source, :package_description, :commit_message) SENSITIVE = [] include Aws::Structure end |
#package_description ⇒ String
New description of the package.
4328 4329 4330 4331 4332 4333 4334 4335 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4328 class UpdatePackageRequest < Struct.new( :package_id, :package_source, :package_description, :commit_message) SENSITIVE = [] include Aws::Structure end |
#package_id ⇒ String
Unique identifier for the package.
4328 4329 4330 4331 4332 4333 4334 4335 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4328 class UpdatePackageRequest < Struct.new( :package_id, :package_source, :package_description, :commit_message) SENSITIVE = [] include Aws::Structure end |
#package_source ⇒ Types::PackageSource
The S3 location for importing the package specified as S3BucketName and S3Key
4328 4329 4330 4331 4332 4333 4334 4335 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4328 class UpdatePackageRequest < Struct.new( :package_id, :package_source, :package_description, :commit_message) SENSITIVE = [] include Aws::Structure end |