Class: Aws::ElasticsearchService::Types::UpgradeElasticsearchDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::UpgradeElasticsearchDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for request parameters to ‘ UpgradeElasticsearchDomain ` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The name of an Elasticsearch domain.
-
#perform_check_only ⇒ Boolean
This flag, when set to True, indicates that an Upgrade Eligibility Check needs to be performed.
-
#target_version ⇒ String
The version of Elasticsearch that you intend to upgrade the domain to.
Instance Attribute Details
#domain_name ⇒ String
The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
4519 4520 4521 4522 4523 4524 4525 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4519 class UpgradeElasticsearchDomainRequest < Struct.new( :domain_name, :target_version, :perform_check_only) SENSITIVE = [] include Aws::Structure end |
#perform_check_only ⇒ Boolean
This flag, when set to True, indicates that an Upgrade Eligibility Check needs to be performed. This will not actually perform the Upgrade.
4519 4520 4521 4522 4523 4524 4525 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4519 class UpgradeElasticsearchDomainRequest < Struct.new( :domain_name, :target_version, :perform_check_only) SENSITIVE = [] include Aws::Structure end |
#target_version ⇒ String
The version of Elasticsearch that you intend to upgrade the domain to.
4519 4520 4521 4522 4523 4524 4525 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4519 class UpgradeElasticsearchDomainRequest < Struct.new( :domain_name, :target_version, :perform_check_only) SENSITIVE = [] include Aws::Structure end |