Class: Aws::ElasticsearchService::Types::UpgradeElasticsearchDomainResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::UpgradeElasticsearchDomainResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for response returned by UpgradeElasticsearchDomain
operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_progress_details ⇒ Types::ChangeProgressDetails
Specifies change details of the domain configuration change.
-
#domain_name ⇒ String
The name of an Elasticsearch domain.
-
#perform_check_only ⇒ Boolean
This flag, when set to True, indicates that an Upgrade Eligibility Check needs to be performed.
-
#target_version ⇒ String
The version of Elasticsearch that you intend to upgrade the domain to.
Instance Attribute Details
#change_progress_details ⇒ Types::ChangeProgressDetails
Specifies change details of the domain configuration change.
4613 4614 4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4613 class UpgradeElasticsearchDomainResponse < Struct.new( :domain_name, :target_version, :perform_check_only, :change_progress_details) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
4613 4614 4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4613 class UpgradeElasticsearchDomainResponse < Struct.new( :domain_name, :target_version, :perform_check_only, :change_progress_details) SENSITIVE = [] include Aws::Structure end |
#perform_check_only ⇒ Boolean
This flag, when set to True, indicates that an Upgrade Eligibility Check needs to be performed. This will not actually perform the Upgrade.
4613 4614 4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4613 class UpgradeElasticsearchDomainResponse < Struct.new( :domain_name, :target_version, :perform_check_only, :change_progress_details) SENSITIVE = [] include Aws::Structure end |
#target_version ⇒ String
The version of Elasticsearch that you intend to upgrade the domain to.
4613 4614 4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4613 class UpgradeElasticsearchDomainResponse < Struct.new( :domain_name, :target_version, :perform_check_only, :change_progress_details) SENSITIVE = [] include Aws::Structure end |