Class: Aws::ElasticsearchService::Types::UseCaseStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticsearchservice/types.rb

Overview

The status of the use case for the domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#optionsString

The use case configured for the domain.

Returns:

  • (String)


4703
4704
4705
4706
4707
4708
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4703

class UseCaseStatus < Struct.new(
  :options,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::OptionStatus

The current status of the use case for the domain.

Returns:



4703
4704
4705
4706
4707
4708
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4703

class UseCaseStatus < Struct.new(
  :options,
  :status)
  SENSITIVE = []
  include Aws::Structure
end