Class: Aws::ElasticsearchService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ElasticsearchService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-elasticsearchservice/client.rb
Overview
An API client for ElasticsearchService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ElasticsearchService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::AcceptInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to accept an inbound cross-cluster search connection request.
-
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Elasticsearch domain.
-
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon ES domain.
-
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
-
#cancel_elasticsearch_service_software_update(params = {}) ⇒ Types::CancelElasticsearchServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon ES domain.
-
#create_elasticsearch_domain(params = {}) ⇒ Types::CreateElasticsearchDomainResponse
Creates a new Elasticsearch domain.
-
#create_outbound_cross_cluster_search_connection(params = {}) ⇒ Types::CreateOutboundCrossClusterSearchConnectionResponse
Creates a new cross-cluster search connection from a source domain to a destination domain.
-
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Create a package for use with Amazon ES domains.
-
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
-
#delete_elasticsearch_domain(params = {}) ⇒ Types::DeleteElasticsearchDomainResponse
Permanently deletes the specified Elasticsearch domain and all of its data.
-
#delete_elasticsearch_service_role(params = {}) ⇒ Struct
Deletes the service-linked role that Elasticsearch Service uses to manage and maintain VPC domains.
-
#delete_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::DeleteInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to delete an existing inbound cross-cluster search connection.
-
#delete_outbound_cross_cluster_search_connection(params = {}) ⇒ Types::DeleteOutboundCrossClusterSearchConnectionResponse
Allows the source domain owner to delete an existing outbound cross-cluster search connection.
-
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Delete the package.
-
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Provides scheduled Auto-Tune action details for the Elasticsearch domain, such as Auto-Tune action type, description, severity, and scheduled date.
-
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on a domain, including a change ID, status, and progress stages.
-
#describe_elasticsearch_domain(params = {}) ⇒ Types::DescribeElasticsearchDomainResponse
Returns domain configuration information about the specified Elasticsearch domain, including the domain ID, domain endpoint, and domain ARN.
-
#describe_elasticsearch_domain_config(params = {}) ⇒ Types::DescribeElasticsearchDomainConfigResponse
Provides cluster configuration information about the specified Elasticsearch domain, such as the state, creation date, update version, and update date for cluster options.
-
#describe_elasticsearch_domains(params = {}) ⇒ Types::DescribeElasticsearchDomainsResponse
Returns domain configuration information about the specified Elasticsearch domains, including the domain ID, domain endpoint, and domain ARN.
-
#describe_elasticsearch_instance_type_limits(params = {}) ⇒ Types::DescribeElasticsearchInstanceTypeLimitsResponse
Describe Elasticsearch Limits for a given InstanceType and ElasticsearchVersion.
-
#describe_inbound_cross_cluster_search_connections(params = {}) ⇒ Types::DescribeInboundCrossClusterSearchConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination domain.
-
#describe_outbound_cross_cluster_search_connections(params = {}) ⇒ Types::DescribeOutboundCrossClusterSearchConnectionsResponse
Lists all the outbound cross-cluster search connections for a source domain.
-
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to Amazon ES.
-
#describe_reserved_elasticsearch_instance_offerings(params = {}) ⇒ Types::DescribeReservedElasticsearchInstanceOfferingsResponse
Lists available reserved Elasticsearch instance offerings.
-
#describe_reserved_elasticsearch_instances(params = {}) ⇒ Types::DescribeReservedElasticsearchInstancesResponse
Returns information about reserved Elasticsearch instances for this account.
-
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
-
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Dissociates a package from the Amazon ES domain.
-
#get_compatible_elasticsearch_versions(params = {}) ⇒ Types::GetCompatibleElasticsearchVersionsResponse
Returns a list of upgrade compatible Elastisearch versions.
-
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of versions of the package, along with their creation time and commit message.
-
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades that were performed on the domain.
-
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.
-
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the name of all Elasticsearch domains owned by the current user’s account.
-
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon ES domains associated with the package.
-
#list_elasticsearch_instance_types(params = {}) ⇒ Types::ListElasticsearchInstanceTypesResponse
List all Elasticsearch instance types that are supported for given ElasticsearchVersion.
-
#list_elasticsearch_versions(params = {}) ⇒ Types::ListElasticsearchVersionsResponse
List all supported Elasticsearch versions.
-
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with the Amazon ES domain.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all tags for the given Elasticsearch domain.
-
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
-
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current account and Region.
-
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
-
#purchase_reserved_elasticsearch_instance_offering(params = {}) ⇒ Types::PurchaseReservedElasticsearchInstanceOfferingResponse
Allows you to purchase reserved Elasticsearch instances.
-
#reject_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::RejectInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to reject an inbound cross-cluster search connection request.
-
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from the specified Elasticsearch domain.
-
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
-
#start_elasticsearch_service_software_update(params = {}) ⇒ Types::StartElasticsearchServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon ES domain.
-
#update_elasticsearch_domain_config(params = {}) ⇒ Types::UpdateElasticsearchDomainConfigResponse
Modifies the cluster configuration of the specified Elasticsearch domain, setting as setting the instance type and the number of instances.
-
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon ES domains.
-
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
-
#upgrade_elasticsearch_domain(params = {}) ⇒ Types::UpgradeElasticsearchDomainResponse
Allows you to either upgrade your domain or perform an Upgrade eligibility check to a compatible Elasticsearch version.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3621 3622 3623 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3621 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3624 3625 3626 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3624 def errors_module Errors end |
Instance Method Details
#accept_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::AcceptInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to accept an inbound cross-cluster search connection request.
507 508 509 510 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 507 def accept_inbound_cross_cluster_search_connection(params = {}, = {}) req = build_request(:accept_inbound_cross_cluster_search_connection, params) req.send_request() end |
#add_tags(params = {}) ⇒ Struct
Attaches tags to an existing Elasticsearch domain. Tags are a set of case-sensitive key value pairs. An Elasticsearch domain may have up to 10 tags. See [ Tagging Amazon Elasticsearch Service Domains for more information.]
543 544 545 546 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 543 def (params = {}, = {}) req = build_request(:add_tags, params) req.send_request() end |
#associate_package(params = {}) ⇒ Types::AssociatePackageResponse
Associates a package with an Amazon ES domain.
583 584 585 586 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 583 def associate_package(params = {}, = {}) req = build_request(:associate_package, params) req.send_request() end |
#authorize_vpc_endpoint_access(params = {}) ⇒ Types::AuthorizeVpcEndpointAccessResponse
Provides access to an Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
615 616 617 618 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 615 def (params = {}, = {}) req = build_request(:authorize_vpc_endpoint_access, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3594 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ElasticsearchService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-elasticsearchservice' context[:gem_version] = '1.121.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_domain_config_change(params = {}) ⇒ Types::CancelDomainConfigChangeResponse
Cancels a pending configuration change on an Amazon OpenSearch Service domain.
655 656 657 658 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 655 def cancel_domain_config_change(params = {}, = {}) req = build_request(:cancel_domain_config_change, params) req.send_request() end |
#cancel_elasticsearch_service_software_update(params = {}) ⇒ Types::CancelElasticsearchServiceSoftwareUpdateResponse
Cancels a scheduled service software update for an Amazon ES domain. You can only perform this operation before the ‘AutomatedUpdateDate` and when the `UpdateStatus` is in the `PENDING_UPDATE` state.
691 692 693 694 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 691 def cancel_elasticsearch_service_software_update(params = {}, = {}) req = build_request(:cancel_elasticsearch_service_software_update, params) req.send_request() end |
#create_elasticsearch_domain(params = {}) ⇒ Types::CreateElasticsearchDomainResponse
Creates a new Elasticsearch domain. For more information, see
- Creating Elasticsearch Domains][1
-
in the *Amazon Elasticsearch
Service Developer Guide*.
1016 1017 1018 1019 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1016 def create_elasticsearch_domain(params = {}, = {}) req = build_request(:create_elasticsearch_domain, params) req.send_request() end |
#create_outbound_cross_cluster_search_connection(params = {}) ⇒ Types::CreateOutboundCrossClusterSearchConnectionResponse
Creates a new cross-cluster search connection from a source domain to a destination domain.
1074 1075 1076 1077 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1074 def create_outbound_cross_cluster_search_connection(params = {}, = {}) req = build_request(:create_outbound_cross_cluster_search_connection, params) req.send_request() end |
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Create a package for use with Amazon ES domains.
1124 1125 1126 1127 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1124 def create_package(params = {}, = {}) req = build_request(:create_package, params) req.send_request() end |
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an Amazon OpenSearch Service-managed VPC endpoint.
1173 1174 1175 1176 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1173 def create_vpc_endpoint(params = {}, = {}) req = build_request(:create_vpc_endpoint, params) req.send_request() end |
#delete_elasticsearch_domain(params = {}) ⇒ Types::DeleteElasticsearchDomainResponse
Permanently deletes the specified Elasticsearch domain and all of its data. Once a domain is deleted, it cannot be recovered.
1290 1291 1292 1293 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1290 def delete_elasticsearch_domain(params = {}, = {}) req = build_request(:delete_elasticsearch_domain, params) req.send_request() end |
#delete_elasticsearch_service_role(params = {}) ⇒ Struct
Deletes the service-linked role that Elasticsearch Service uses to manage and maintain VPC domains. Role deletion will fail if any existing VPC domains use the role. You must delete any such Elasticsearch domains before deleting the role. See [Deleting Elasticsearch Service Role] in *VPC Endpoints for Amazon Elasticsearch Service Domains*.
[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html#es-enabling-slr
1310 1311 1312 1313 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1310 def delete_elasticsearch_service_role(params = {}, = {}) req = build_request(:delete_elasticsearch_service_role, params) req.send_request() end |
#delete_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::DeleteInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to delete an existing inbound cross-cluster search connection.
1345 1346 1347 1348 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1345 def delete_inbound_cross_cluster_search_connection(params = {}, = {}) req = build_request(:delete_inbound_cross_cluster_search_connection, params) req.send_request() end |
#delete_outbound_cross_cluster_search_connection(params = {}) ⇒ Types::DeleteOutboundCrossClusterSearchConnectionResponse
Allows the source domain owner to delete an existing outbound cross-cluster search connection.
1381 1382 1383 1384 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1381 def delete_outbound_cross_cluster_search_connection(params = {}, = {}) req = build_request(:delete_outbound_cross_cluster_search_connection, params) req.send_request() end |
#delete_package(params = {}) ⇒ Types::DeletePackageResponse
Delete the package.
1417 1418 1419 1420 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1417 def delete_package(params = {}, = {}) req = build_request(:delete_package, params) req.send_request() end |
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an Amazon OpenSearch Service-managed interface VPC endpoint.
1446 1447 1448 1449 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1446 def delete_vpc_endpoint(params = {}, = {}) req = build_request(:delete_vpc_endpoint, params) req.send_request() end |
#describe_domain_auto_tunes(params = {}) ⇒ Types::DescribeDomainAutoTunesResponse
Provides scheduled Auto-Tune action details for the Elasticsearch domain, such as Auto-Tune action type, description, severity, and scheduled date.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1493 1494 1495 1496 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1493 def describe_domain_auto_tunes(params = {}, = {}) req = build_request(:describe_domain_auto_tunes, params) req.send_request() end |
#describe_domain_change_progress(params = {}) ⇒ Types::DescribeDomainChangeProgressResponse
Returns information about the current blue/green deployment happening on a domain, including a change ID, status, and progress stages.
1541 1542 1543 1544 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1541 def describe_domain_change_progress(params = {}, = {}) req = build_request(:describe_domain_change_progress, params) req.send_request() end |
#describe_elasticsearch_domain(params = {}) ⇒ Types::DescribeElasticsearchDomainResponse
Returns domain configuration information about the specified Elasticsearch domain, including the domain ID, domain endpoint, and domain ARN.
1658 1659 1660 1661 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1658 def describe_elasticsearch_domain(params = {}, = {}) req = build_request(:describe_elasticsearch_domain, params) req.send_request() end |
#describe_elasticsearch_domain_config(params = {}) ⇒ Types::DescribeElasticsearchDomainConfigResponse
Provides cluster configuration information about the specified Elasticsearch domain, such as the state, creation date, update version, and update date for cluster options.
1842 1843 1844 1845 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1842 def describe_elasticsearch_domain_config(params = {}, = {}) req = build_request(:describe_elasticsearch_domain_config, params) req.send_request() end |
#describe_elasticsearch_domains(params = {}) ⇒ Types::DescribeElasticsearchDomainsResponse
Returns domain configuration information about the specified Elasticsearch domains, including the domain ID, domain endpoint, and domain ARN.
1960 1961 1962 1963 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 1960 def describe_elasticsearch_domains(params = {}, = {}) req = build_request(:describe_elasticsearch_domains, params) req.send_request() end |
#describe_elasticsearch_instance_type_limits(params = {}) ⇒ Types::DescribeElasticsearchInstanceTypeLimitsResponse
Describe Elasticsearch Limits for a given InstanceType and ElasticsearchVersion. When modifying existing Domain, specify the ‘ DomainName ` to know what Limits are supported for modifying.
2012 2013 2014 2015 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2012 def describe_elasticsearch_instance_type_limits(params = {}, = {}) req = build_request(:describe_elasticsearch_instance_type_limits, params) req.send_request() end |
#describe_inbound_cross_cluster_search_connections(params = {}) ⇒ Types::DescribeInboundCrossClusterSearchConnectionsResponse
Lists all the inbound cross-cluster search connections for a destination domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2073 2074 2075 2076 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2073 def describe_inbound_cross_cluster_search_connections(params = {}, = {}) req = build_request(:describe_inbound_cross_cluster_search_connections, params) req.send_request() end |
#describe_outbound_cross_cluster_search_connections(params = {}) ⇒ Types::DescribeOutboundCrossClusterSearchConnectionsResponse
Lists all the outbound cross-cluster search connections for a source domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2135 2136 2137 2138 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2135 def describe_outbound_cross_cluster_search_connections(params = {}, = {}) req = build_request(:describe_outbound_cross_cluster_search_connections, params) req.send_request() end |
#describe_packages(params = {}) ⇒ Types::DescribePackagesResponse
Describes all packages available to Amazon ES. Includes options for filtering, limiting the number of results, and pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2192 2193 2194 2195 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2192 def describe_packages(params = {}, = {}) req = build_request(:describe_packages, params) req.send_request() end |
#describe_reserved_elasticsearch_instance_offerings(params = {}) ⇒ Types::DescribeReservedElasticsearchInstanceOfferingsResponse
Lists available reserved Elasticsearch instance offerings.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2244 2245 2246 2247 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2244 def describe_reserved_elasticsearch_instance_offerings(params = {}, = {}) req = build_request(:describe_reserved_elasticsearch_instance_offerings, params) req.send_request() end |
#describe_reserved_elasticsearch_instances(params = {}) ⇒ Types::DescribeReservedElasticsearchInstancesResponse
Returns information about reserved Elasticsearch instances for this account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2302 2303 2304 2305 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2302 def describe_reserved_elasticsearch_instances(params = {}, = {}) req = build_request(:describe_reserved_elasticsearch_instances, params) req.send_request() end |
#describe_vpc_endpoints(params = {}) ⇒ Types::DescribeVpcEndpointsResponse
Describes one or more Amazon OpenSearch Service-managed VPC endpoints.
2345 2346 2347 2348 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2345 def describe_vpc_endpoints(params = {}, = {}) req = build_request(:describe_vpc_endpoints, params) req.send_request() end |
#dissociate_package(params = {}) ⇒ Types::DissociatePackageResponse
Dissociates a package from the Amazon ES domain.
2385 2386 2387 2388 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2385 def dissociate_package(params = {}, = {}) req = build_request(:dissociate_package, params) req.send_request() end |
#get_compatible_elasticsearch_versions(params = {}) ⇒ Types::GetCompatibleElasticsearchVersionsResponse
Returns a list of upgrade compatible Elastisearch versions. You can optionally pass a ‘ DomainName ` to get all upgrade compatible Elasticsearch versions for that specific domain.
2419 2420 2421 2422 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2419 def get_compatible_elasticsearch_versions(params = {}, = {}) req = build_request(:get_compatible_elasticsearch_versions, params) req.send_request() end |
#get_package_version_history(params = {}) ⇒ Types::GetPackageVersionHistoryResponse
Returns a list of versions of the package, along with their creation time and commit message.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2465 2466 2467 2468 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2465 def get_package_version_history(params = {}, = {}) req = build_request(:get_package_version_history, params) req.send_request() end |
#get_upgrade_history(params = {}) ⇒ Types::GetUpgradeHistoryResponse
Retrieves the complete history of the last 10 upgrades that were performed on the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2518 2519 2520 2521 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2518 def get_upgrade_history(params = {}, = {}) req = build_request(:get_upgrade_history, params) req.send_request() end |
#get_upgrade_status(params = {}) ⇒ Types::GetUpgradeStatusResponse
Retrieves the latest status of the last upgrade or upgrade eligibility check that was performed on the domain.
2552 2553 2554 2555 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2552 def get_upgrade_status(params = {}, = {}) req = build_request(:get_upgrade_status, params) req.send_request() end |
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Returns the name of all Elasticsearch domains owned by the current user’s account.
2582 2583 2584 2585 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2582 def list_domain_names(params = {}, = {}) req = build_request(:list_domain_names, params) req.send_request() end |
#list_domains_for_package(params = {}) ⇒ Types::ListDomainsForPackageResponse
Lists all Amazon ES domains associated with the package.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2632 2633 2634 2635 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2632 def list_domains_for_package(params = {}, = {}) req = build_request(:list_domains_for_package, params) req.send_request() end |
#list_elasticsearch_instance_types(params = {}) ⇒ Types::ListElasticsearchInstanceTypesResponse
List all Elasticsearch instance types that are supported for given ElasticsearchVersion
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2681 2682 2683 2684 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2681 def list_elasticsearch_instance_types(params = {}, = {}) req = build_request(:list_elasticsearch_instance_types, params) req.send_request() end |
#list_elasticsearch_versions(params = {}) ⇒ Types::ListElasticsearchVersionsResponse
List all supported Elasticsearch versions
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2719 2720 2721 2722 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2719 def list_elasticsearch_versions(params = {}, = {}) req = build_request(:list_elasticsearch_versions, params) req.send_request() end |
#list_packages_for_domain(params = {}) ⇒ Types::ListPackagesForDomainResponse
Lists all packages associated with the Amazon ES domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2769 2770 2771 2772 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2769 def list_packages_for_domain(params = {}, = {}) req = build_request(:list_packages_for_domain, params) req.send_request() end |
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns all tags for the given Elasticsearch domain.
2798 2799 2800 2801 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2798 def (params = {}, = {}) req = build_request(:list_tags, params) req.send_request() end |
#list_vpc_endpoint_access(params = {}) ⇒ Types::ListVpcEndpointAccessResponse
Retrieves information about each principal that is allowed to access a given Amazon OpenSearch Service domain through the use of an interface VPC endpoint.
2835 2836 2837 2838 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2835 def list_vpc_endpoint_access(params = {}, = {}) req = build_request(:list_vpc_endpoint_access, params) req.send_request() end |
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints in the current account and Region.
2868 2869 2870 2871 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2868 def list_vpc_endpoints(params = {}, = {}) req = build_request(:list_vpc_endpoints, params) req.send_request() end |
#list_vpc_endpoints_for_domain(params = {}) ⇒ Types::ListVpcEndpointsForDomainResponse
Retrieves all Amazon OpenSearch Service-managed VPC endpoints associated with a particular domain.
2905 2906 2907 2908 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2905 def list_vpc_endpoints_for_domain(params = {}, = {}) req = build_request(:list_vpc_endpoints_for_domain, params) req.send_request() end |
#purchase_reserved_elasticsearch_instance_offering(params = {}) ⇒ Types::PurchaseReservedElasticsearchInstanceOfferingResponse
Allows you to purchase reserved Elasticsearch instances.
2941 2942 2943 2944 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2941 def purchase_reserved_elasticsearch_instance_offering(params = {}, = {}) req = build_request(:purchase_reserved_elasticsearch_instance_offering, params) req.send_request() end |
#reject_inbound_cross_cluster_search_connection(params = {}) ⇒ Types::RejectInboundCrossClusterSearchConnectionResponse
Allows the destination domain owner to reject an inbound cross-cluster search connection request.
2976 2977 2978 2979 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 2976 def reject_inbound_cross_cluster_search_connection(params = {}, = {}) req = build_request(:reject_inbound_cross_cluster_search_connection, params) req.send_request() end |
#remove_tags(params = {}) ⇒ Struct
Removes the specified set of tags from the specified Elasticsearch domain.
3003 3004 3005 3006 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3003 def (params = {}, = {}) req = build_request(:remove_tags, params) req.send_request() end |
#revoke_vpc_endpoint_access(params = {}) ⇒ Struct
Revokes access to an Amazon OpenSearch Service domain that was provided through an interface VPC endpoint.
3028 3029 3030 3031 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3028 def revoke_vpc_endpoint_access(params = {}, = {}) req = build_request(:revoke_vpc_endpoint_access, params) req.send_request() end |
#start_elasticsearch_service_software_update(params = {}) ⇒ Types::StartElasticsearchServiceSoftwareUpdateResponse
Schedules a service software update for an Amazon ES domain.
3062 3063 3064 3065 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3062 def start_elasticsearch_service_software_update(params = {}, = {}) req = build_request(:start_elasticsearch_service_software_update, params) req.send_request() end |
#update_elasticsearch_domain_config(params = {}) ⇒ Types::UpdateElasticsearchDomainConfigResponse
Modifies the cluster configuration of the specified Elasticsearch domain, setting as setting the instance type and the number of instances.
3438 3439 3440 3441 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3438 def update_elasticsearch_domain_config(params = {}, = {}) req = build_request(:update_elasticsearch_domain_config, params) req.send_request() end |
#update_package(params = {}) ⇒ Types::UpdatePackageResponse
Updates a package for use with Amazon ES domains.
3490 3491 3492 3493 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3490 def update_package(params = {}, = {}) req = build_request(:update_package, params) req.send_request() end |
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Modifies an Amazon OpenSearch Service-managed interface VPC endpoint.
3534 3535 3536 3537 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3534 def update_vpc_endpoint(params = {}, = {}) req = build_request(:update_vpc_endpoint, params) req.send_request() end |
#upgrade_elasticsearch_domain(params = {}) ⇒ Types::UpgradeElasticsearchDomainResponse
Allows you to either upgrade your domain or perform an Upgrade eligibility check to a compatible Elasticsearch version.
3585 3586 3587 3588 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3585 def upgrade_elasticsearch_domain(params = {}, = {}) req = build_request(:upgrade_elasticsearch_domain, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3614 3615 3616 |
# File 'lib/aws-sdk-elasticsearchservice/client.rb', line 3614 def waiter_names [] end |