Class: Aws::ElasticsearchService::Types::DescribeDomainChangeProgressRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::DescribeDomainChangeProgressRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Container for the parameters to the DescribeDomainChangeProgress
operation. Specifies the domain name and optional change specific
identity for which you want progress information.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_id ⇒ String
The specific change ID for which you want to get progress information.
-
#domain_name ⇒ String
The domain you want to get the progress information about.
Instance Attribute Details
#change_id ⇒ String
The specific change ID for which you want to get progress information. This is an optional parameter. If omitted, the service returns information about the most recent configuration change.
1482 1483 1484 1485 1486 1487 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1482 class DescribeDomainChangeProgressRequest < Struct.new( :domain_name, :change_id) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The domain you want to get the progress information about.
1482 1483 1484 1485 1486 1487 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 1482 class DescribeDomainChangeProgressRequest < Struct.new( :domain_name, :change_id) SENSITIVE = [] include Aws::Structure end |