Class: Aws::ElasticsearchService::Types::DryRunResults
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::DryRunResults
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deployment_type ⇒ String
Specifies the deployment mechanism through which the update shall be applied on the domain.
-
#message ⇒ String
Contains an optional message associated with the DryRunResults.
Instance Attribute Details
#deployment_type ⇒ String
Specifies the deployment mechanism through which the update shall be
applied on the domain. Possible responses are Blue/Green (The
update will require a blue/green deployment.) DynamicUpdate (The
update can be applied in-place without a Blue/Green deployment
required.) Undetermined (The domain is undergoing an update which
needs to complete before the deployment type can be predicted.)
None (The configuration change matches the current configuration
and will not result in any update.)
2117 2118 2119 2120 2121 2122 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2117 class DryRunResults < Struct.new( :deployment_type, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
Contains an optional message associated with the DryRunResults.
2117 2118 2119 2120 2121 2122 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2117 class DryRunResults < Struct.new( :deployment_type, :message) SENSITIVE = [] include Aws::Structure end |