Class: Aws::ElasticsearchService::Types::ElasticsearchClusterConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::ElasticsearchClusterConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
Specifies the configuration for the domain cluster, such as the type and number of instances.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cold_storage_options ⇒ Types::ColdStorageOptions
Specifies the ‘ColdStorageOptions` config for Elasticsearch Domain.
-
#dedicated_master_count ⇒ Integer
Total number of dedicated master nodes, active and on standby, for the cluster.
-
#dedicated_master_enabled ⇒ Boolean
A boolean value to indicate whether a dedicated master node is enabled.
-
#dedicated_master_type ⇒ String
The instance type for a dedicated master node.
-
#instance_count ⇒ Integer
The number of instances in the specified domain cluster.
-
#instance_type ⇒ String
The instance type for an Elasticsearch cluster.
-
#warm_count ⇒ Integer
The number of warm nodes in the cluster.
-
#warm_enabled ⇒ Boolean
True to enable warm storage.
-
#warm_type ⇒ String
The instance type for the Elasticsearch cluster’s warm nodes.
-
#zone_awareness_config ⇒ Types::ZoneAwarenessConfig
Specifies the zone awareness configuration for a domain when zone awareness is enabled.
-
#zone_awareness_enabled ⇒ Boolean
A boolean value to indicate whether zone awareness is enabled.
Instance Attribute Details
#cold_storage_options ⇒ Types::ColdStorageOptions
Specifies the ‘ColdStorageOptions` config for Elasticsearch Domain
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#dedicated_master_count ⇒ Integer
Total number of dedicated master nodes, active and on standby, for the cluster.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#dedicated_master_enabled ⇒ Boolean
A boolean value to indicate whether a dedicated master node is enabled. See [About Dedicated Master Nodes] for more information.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#dedicated_master_type ⇒ String
The instance type for a dedicated master node.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#instance_count ⇒ Integer
The number of instances in the specified domain cluster.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type for an Elasticsearch cluster. UltraWarm instance types are not supported for data instances.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#warm_count ⇒ Integer
The number of warm nodes in the cluster.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#warm_enabled ⇒ Boolean
True to enable warm storage.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#warm_type ⇒ String
The instance type for the Elasticsearch cluster’s warm nodes.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#zone_awareness_config ⇒ Types::ZoneAwarenessConfig
Specifies the zone awareness configuration for a domain when zone awareness is enabled.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |
#zone_awareness_enabled ⇒ Boolean
A boolean value to indicate whether zone awareness is enabled. See
- About Zone Awareness][1
-
for more information.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2260 class ElasticsearchClusterConfig < Struct.new( :instance_type, :instance_count, :dedicated_master_enabled, :zone_awareness_enabled, :zone_awareness_config, :dedicated_master_type, :dedicated_master_count, :warm_enabled, :warm_type, :warm_count, :cold_storage_options) SENSITIVE = [] include Aws::Structure end |