Class: Aws::ElasticsearchService::Types::ElasticsearchDomainStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::ElasticsearchDomainStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
The current status of an Elasticsearch domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_policies ⇒ String
IAM access policy as a JSON-formatted string.
-
#advanced_options ⇒ Hash<String,String>
Specifies the status of the ‘AdvancedOptions`.
-
#advanced_security_options ⇒ Types::AdvancedSecurityOptions
The current status of the Elasticsearch domain’s advanced security options.
-
#arn ⇒ String
The Amazon resource name (ARN) of an Elasticsearch domain.
-
#auto_tune_options ⇒ Types::AutoTuneOptionsOutput
The current status of the Elasticsearch domain’s Auto-Tune options.
-
#automated_snapshot_pause_options ⇒ Types::AutomatedSnapshotPauseOptions
The current status of the Elasticsearch domain’s automated snapshot pause options.
-
#change_progress_details ⇒ Types::ChangeProgressDetails
Specifies change details of the domain configuration change.
-
#cognito_options ⇒ Types::CognitoOptions
The ‘CognitoOptions` for the specified domain.
-
#created ⇒ Boolean
The domain creation status.
-
#deleted ⇒ Boolean
The domain deletion status.
-
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptions
The current status of the Elasticsearch domain’s deployment strategy options.
-
#domain_endpoint_options ⇒ Types::DomainEndpointOptions
The current status of the Elasticsearch domain’s endpoint options.
-
#domain_id ⇒ String
The unique identifier for the specified Elasticsearch domain.
-
#domain_name ⇒ String
The name of an Elasticsearch domain.
-
#domain_processing_status ⇒ String
The status of any changes that are currently in progress for the domain.
-
#ebs_options ⇒ Types::EBSOptions
The ‘EBSOptions` for the specified domain.
-
#elasticsearch_cluster_config ⇒ Types::ElasticsearchClusterConfig
The type and number of instances in the domain cluster.
- #elasticsearch_version ⇒ String
-
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptions
Specifies the status of the ‘EncryptionAtRestOptions`.
-
#endpoint ⇒ String
The Elasticsearch domain endpoint that you use to submit index and search requests.
-
#endpoints ⇒ Hash<String,String>
Map containing the Elasticsearch domain endpoints used to submit index and search requests.
-
#log_publishing_options ⇒ Hash<String,Types::LogPublishingOption>
Log publishing options for the given domain.
-
#modifying_properties ⇒ Array<Types::ModifyingProperties>
Information about the domain properties that are currently being modified.
-
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptions
Specifies the status of the ‘NodeToNodeEncryptionOptions`.
-
#processing ⇒ Boolean
The status of the Elasticsearch domain configuration.
-
#service_software_options ⇒ Types::ServiceSoftwareOptions
The current status of the Elasticsearch domain’s service software.
-
#snapshot_options ⇒ Types::SnapshotOptions
Specifies the status of the ‘SnapshotOptions`.
-
#upgrade_processing ⇒ Boolean
The status of an Elasticsearch domain version upgrade.
-
#vpc_options ⇒ Types::VPCDerivedInfo
The ‘VPCOptions` for the specified domain.
Instance Attribute Details
#access_policies ⇒ String
IAM access policy as a JSON-formatted string.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#advanced_options ⇒ Hash<String,String>
Specifies the status of the ‘AdvancedOptions`
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#advanced_security_options ⇒ Types::AdvancedSecurityOptions
The current status of the Elasticsearch domain’s advanced security options.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon resource name (ARN) of an Elasticsearch domain. See
- Identifiers for IAM Entities][1
-
in *Using AWS Identity and Access
Management* for more information.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/index.html?Using_Identifiers.html
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#auto_tune_options ⇒ Types::AutoTuneOptionsOutput
The current status of the Elasticsearch domain’s Auto-Tune options.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#automated_snapshot_pause_options ⇒ Types::AutomatedSnapshotPauseOptions
The current status of the Elasticsearch domain’s automated snapshot pause options.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#change_progress_details ⇒ Types::ChangeProgressDetails
Specifies change details of the domain configuration change.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#cognito_options ⇒ Types::CognitoOptions
The ‘CognitoOptions` for the specified domain. For more information, see [Amazon Cognito Authentication for Kibana].
[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-cognito-auth.html
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#created ⇒ Boolean
The domain creation status. ‘True` if the creation of an Elasticsearch domain is complete. `False` if domain creation is still in progress.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#deleted ⇒ Boolean
The domain deletion status. ‘True` if a delete request has been received for the domain but resource cleanup is still in progress. `False` if the domain has not been deleted. Once domain deletion is complete, the status of the domain is no longer returned.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#deployment_strategy_options ⇒ Types::DeploymentStrategyOptions
The current status of the Elasticsearch domain’s deployment strategy options.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#domain_endpoint_options ⇒ Types::DomainEndpointOptions
The current status of the Elasticsearch domain’s endpoint options.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The unique identifier for the specified Elasticsearch domain.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#domain_processing_status ⇒ String
The status of any changes that are currently in progress for the domain.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#ebs_options ⇒ Types::EBSOptions
The ‘EBSOptions` for the specified domain. See [Configuring EBS-based Storage] for more information.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_cluster_config ⇒ Types::ElasticsearchClusterConfig
The type and number of instances in the domain cluster.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#elasticsearch_version ⇒ String
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#encryption_at_rest_options ⇒ Types::EncryptionAtRestOptions
Specifies the status of the ‘EncryptionAtRestOptions`.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The Elasticsearch domain endpoint that you use to submit index and search requests.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#endpoints ⇒ Hash<String,String>
Map containing the Elasticsearch domain endpoints used to submit index and search requests. Example ‘key, value`: `’vpc’,‘vpc-endpoint-h2dsd34efgyghrtguk5gt6j2foh4.us-east-1.es.amazonaws.com’‘.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#log_publishing_options ⇒ Hash<String,Types::LogPublishingOption>
Log publishing options for the given domain.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#modifying_properties ⇒ Array<Types::ModifyingProperties>
Information about the domain properties that are currently being modified.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#node_to_node_encryption_options ⇒ Types::NodeToNodeEncryptionOptions
Specifies the status of the ‘NodeToNodeEncryptionOptions`.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#processing ⇒ Boolean
The status of the Elasticsearch domain configuration. ‘True` if Amazon Elasticsearch Service is processing configuration changes. `False` if the configuration is active.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#service_software_options ⇒ Types::ServiceSoftwareOptions
The current status of the Elasticsearch domain’s service software.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#snapshot_options ⇒ Types::SnapshotOptions
Specifies the status of the ‘SnapshotOptions`
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#upgrade_processing ⇒ Boolean
The status of an Elasticsearch domain version upgrade. ‘True` if Amazon Elasticsearch Service is undergoing a version upgrade. `False` if the configuration is active.
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |
#vpc_options ⇒ Types::VPCDerivedInfo
The ‘VPCOptions` for the specified domain. For more information, see [VPC Endpoints for Amazon Elasticsearch Service Domains].
[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 2571 class ElasticsearchDomainStatus < Struct.new( :domain_id, :domain_name, :arn, :created, :deleted, :endpoint, :endpoints, :processing, :upgrade_processing, :elasticsearch_version, :elasticsearch_cluster_config, :ebs_options, :access_policies, :snapshot_options, :vpc_options, :cognito_options, :encryption_at_rest_options, :node_to_node_encryption_options, :advanced_options, :log_publishing_options, :service_software_options, :domain_endpoint_options, :advanced_security_options, :auto_tune_options, :change_progress_details, :domain_processing_status, :modifying_properties, :deployment_strategy_options, :automated_snapshot_pause_options) SENSITIVE = [] include Aws::Structure end |