Class: Aws::ElasticsearchService::Types::StorageType

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticsearchservice/types.rb

Overview

StorageTypes represents the list of storage related types and their attributes that are available for given InstanceType.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#storage_sub_type_nameString

SubType of the given storage type. List of available sub-storage options: For "instance" storageType we wont have any storageSubType, in case of "ebs" storageType we will have following valid storageSubTypes 1. standard 2. gp2 3. gp3 4. io1

Refer VolumeType for more information regarding above EBS storage options.

Returns:

  • (String)


4227
4228
4229
4230
4231
4232
4233
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4227

class StorageType < Struct.new(
  :storage_type_name,
  :storage_sub_type_name,
  :storage_type_limits)
  SENSITIVE = []
  include Aws::Structure
end

#storage_type_limitsArray<Types::StorageTypeLimit>

List of limits that are applicable for given storage type.

Returns:



4227
4228
4229
4230
4231
4232
4233
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4227

class StorageType < Struct.new(
  :storage_type_name,
  :storage_sub_type_name,
  :storage_type_limits)
  SENSITIVE = []
  include Aws::Structure
end

#storage_type_nameString

Type of the storage. List of available storage options: 1. instance 2. ebs

Returns:

  • (String)


4227
4228
4229
4230
4231
4232
4233
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4227

class StorageType < Struct.new(
  :storage_type_name,
  :storage_sub_type_name,
  :storage_type_limits)
  SENSITIVE = []
  include Aws::Structure
end