Class: Aws::ElasticsearchService::Types::UpdateElasticsearchDomainConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticsearchservice/types.rb

Overview

Container for the parameters to the ‘UpdateElasticsearchDomain` operation. Specifies the type and number of instances in the domain cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_policiesString

IAM access policy as a JSON-formatted string.

Returns:

  • (String)


4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#advanced_optionsHash<String,String>

Modifies the advanced option to allow references to indices in an HTTP request body. Must be ‘false` when configuring access to individual sub-resources. By default, the value is `true`. See

Configuration Advanced Options][1

for more information.

[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-createupdatedomains.html#es-createdomain-configure-advanced-options

Returns:

  • (Hash<String,String>)


4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#advanced_security_optionsTypes::AdvancedSecurityOptionsInput

Specifies advanced security options.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#auto_tune_optionsTypes::AutoTuneOptions

Specifies Auto-Tune options.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#automated_snapshot_pause_optionsTypes::AutomatedSnapshotPauseRequestOptions

Specifies the automated snapshot pause options for the domain.

Suspending snapshots reduces data protection. You cannot restore your domain to points in time when snapshots are suspended. Use this feature only for short-term operational needs such as migrations or maintenance windows.

Maximum suspension duration: 3 days.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#cognito_optionsTypes::CognitoOptions

Options to specify the Cognito user and identity pools for Kibana authentication. For more information, see [Amazon Cognito Authentication for Kibana].

[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-cognito-auth.html



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_strategy_optionsTypes::DeploymentStrategyOptions

Specifies the deployment strategy options.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_endpoint_optionsTypes::DomainEndpointOptions

Options to specify configuration that will be applied to the domain endpoint.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The name of the Elasticsearch domain that you are updating.

Returns:

  • (String)


4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

This flag, when set to True, specifies whether the ‘UpdateElasticsearchDomain` request should return the results of validation checks without actually applying the change. This flag, when set to True, specifies the deployment mechanism through which the update shall be applied on the domain. This will not actually perform the Update.

Returns:

  • (Boolean)


4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#ebs_optionsTypes::EBSOptions

Specify the type and size of the EBS volume that you want to use.

Returns:



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#elasticsearch_cluster_configTypes::ElasticsearchClusterConfig

The type and number of instances to instantiate for the domain cluster.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_at_rest_optionsTypes::EncryptionAtRestOptions

Specifies the Encryption At Rest Options.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#log_publishing_optionsHash<String,Types::LogPublishingOption>

Map of ‘LogType` and `LogPublishingOption`, each containing options to publish a given type of Elasticsearch log.

Returns:



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#node_to_node_encryption_optionsTypes::NodeToNodeEncryptionOptions

Specifies the NodeToNodeEncryptionOptions.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_optionsTypes::SnapshotOptions

Option to set the time, in UTC format, for the daily automated snapshot. Default value is ‘0` hours.



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_optionsTypes::VPCOptions

Options to specify the subnets and security groups for VPC endpoint. For more information, see [Creating a VPC] in *VPC Endpoints for Amazon Elasticsearch Service Domains*

[1]: docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-vpc.html#es-creating-vpc

Returns:



4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4387

class UpdateElasticsearchDomainConfigRequest < Struct.new(
  :domain_name,
  :elasticsearch_cluster_config,
  :ebs_options,
  :snapshot_options,
  :vpc_options,
  :cognito_options,
  :advanced_options,
  :access_policies,
  :log_publishing_options,
  :domain_endpoint_options,
  :advanced_security_options,
  :node_to_node_encryption_options,
  :encryption_at_rest_options,
  :auto_tune_options,
  :dry_run,
  :deployment_strategy_options,
  :automated_snapshot_pause_options)
  SENSITIVE = []
  include Aws::Structure
end