Class: Aws::ElasticsearchService::Types::UseCaseStatus
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElasticsearchService::Types::UseCaseStatus
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticsearchservice/types.rb
Overview
The status of the use case for the domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#options ⇒ String
The use case configured for the domain.
-
#status ⇒ Types::OptionStatus
The current status of the use case for the domain.
Instance Attribute Details
#options ⇒ String
The use case configured for the domain.
4703 4704 4705 4706 4707 4708 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4703 class UseCaseStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OptionStatus
The current status of the use case for the domain.
4703 4704 4705 4706 4707 4708 |
# File 'lib/aws-sdk-elasticsearchservice/types.rb', line 4703 class UseCaseStatus < Struct.new( :options, :status) SENSITIVE = [] include Aws::Structure end |